All Classes and Interfaces

Class
Description
Baseboard data
Abstract base class for BluetoothDevice implementations.
A CPU.
Computer System data.
A Display
Common methods for filesystem implementations
Firmware data.
Memory info.
An abstract Graphics Card
Common fields or methods used by platform-specific implementations of HardwareAbstractionLayer
Common methods for platform HWDiskStore classes
Common implementations for IP Stats
Common implementations for LogicalVolumeGroup.
Network interfaces implementation.
Common NetworkParams implementation.
Common methods for OperatingSystem implementations
Common implementations for OSFileStore
A process is an instance of a computer program that is being executed.
Common methods for OSThread implementation
A Power Source
Abstract base class for Printer implementations.
Abstract base for the /proc-filesystem Unix OSProcess implementations (Solaris and AIX).
Sensors from WMI or Open Hardware Monitor
An abstract Sound Card
A USB device
Virtual Memory info.
Baseboard data obtained by lscfg
Abstract base for AIX CentralProcessor.
Tick values OSHI consumes from perfstat_cpu_total_t and perfstat_cpu_t.
Aggregate perfstat_cpu_total_t values OSHI consumes.
Partition fields the CPU init path needs from perfstat_partition_config_t.
Hardware data obtained from lsattr
The AIX File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Firmware data.
Abstract base for AIX GlobalMemory.
Graphics Card info obtained from lscfg
Abstract base for AIX HWDiskStore.
Per-disk stats fields the AIX HAL reads.
 
Abstract base for AIX InternetProtocolStats.
Pure-Java mirror of the AIX lwpsinfo_t struct populated from /proc/<pid>/lwp/<tid>/lwpsinfo.
Abstract base for AIX NetworkIF.
Per-interface stats fields the AIX HAL reads.
Abstract base for AIX NetworkParams.
OSFileStore implementation
Abstract base for AIX OSProcess.
AIX OSThread implementation.
A Power Source
Maps AIX pr_sname characters (from psinfo_t / lwpsinfo_t) to OSHI's OSProcess.State enum.
Pure-Java mirror of the AIX psinfo_t struct populated from /proc/<pid>/psinfo.
Sensors not available except counting fans from lscfg
AIX Sound Card.
AIX Usb Device
Abstract base for AIX VirtualMemory.
Represents common information about an installed application across different operating systems.
Constants and shared logic for the Linux auxiliary vector (/proc/self/auxv).
Reads a native-long value from a ByteBuffer and returns it as a Java long.
The Baseboard represents the system board, also called motherboard, logic board, etc.
Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
Shared CentralProcessor logic for the dmesg-parsing BSDs (OpenBSD and NetBSD).
Shared graphics card implementation for BSDs that use pcidump -v to enumerate PCI devices (NetBSD, OpenBSD).
BsdNetworkIF applicable to FreeBSD and OpenBSD.
Abstract base shared by the BSD-family OperatingSystem implementations (FreeBSD, OpenBSD, DragonFly, NetBSD).
Abstract base shared by the BSD-family OSProcess implementations (FreeBSD, OpenBSD, DragonFly, NetBSD).
Abstract base shared by the BSD-family OSThread implementations (FreeBSD, OpenBSD, DragonFly, NetBSD).
Shared power-source implementation for BSDs that use apm and systat -ab sensors for battery state (NetBSD, OpenBSD).
The union of ps output columns used by the BSD-family OSProcess implementations (FreeBSD, OpenBSD, DragonFly, NetBSD).
The union of ps thread (per-LWP) output columns used by the BSD-family OSThread implementations (FreeBSD, OpenBSD, DragonFly, NetBSD).
Shared sensors implementation for BSDs that use systat for temperature, fan speed, and voltage (NetBSD, OpenBSD).
Shared sound card implementation for BSDs that use dmesg audio/pci patterns (NetBSD, OpenBSD).
Shared USB device implementation for BSDs that use usbdevs -v to enumerate devices (NetBSD, OpenBSD).
This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
A class representing CPU Cache Memory.
The type of cache.
A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
Represents cgroup (control group) information for containerized environments.
The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
General constants used in multiple classes
Utility to read CPU info from /proc/cpuinfo
Utility to read CPU statistics from /proc/stat
CUPS-based printer implementation with shared lpstat fallback logic.
Factory interface for creating concrete printer instances.
Utility to read info from the devicetree
Provides constants for paths in the /dev filesystem on Linux.
Utility class parsing partition information from the BSD disklabel command.
Utility to read disk statistics from /proc/diskstats
Enum corresponding to the fields in the output of /proc/diskstats
Display refers to the information regarding a video source and monitor identified by the EDID standard.
Utility to read info from dmidecode
Abstract base shared by the DragonFly BSD OperatingSystem implementations (JNA and FFM).
 
OSThread implementation
Utility to read EDID data from the Linux DRM (Direct Rendering Manager) subsystem.
Immutable snapshot of a DXGI adapter's identity and dedicated video memory.
Shared utility methods for DXGI adapter matching and related parsing.
EDID parsing utility.
Utility methods for reducing repetitive exception handling boilerplate, particularly around FFM (Foreign Function and Memory) native calls that require catching Throwable.
A boolean-returning supplier that may throw any Throwable.
A double-returning supplier that may throw any Throwable.
An int-returning supplier that may throw any Throwable.
A long-returning supplier that may throw any Throwable.
A runnable that may throw any Throwable.
A supplier that may throw any Throwable, including checked exceptions.
A class for executing on the command line and returning the result of execution.
The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
Utility class for common filesystem code
File reading methods
The Firmware represents the low level BIOS or equivalent.
Formatting utility for appending units or converting between number types.
Shared FreeBSD CentralProcessor logic.
 
 
Firmware information from dmidecode
 
Graphics Card info obtained from pciconf
Shared FreeBSD HWDiskStore logic.
Factory for creating platform-specific FreeBsdHWDiskStore instances.
 
 
Abstract base shared by the FreeBSD OperatingSystem implementations (JNA and FFM).
OSFileStore implementation.
 
OSThread implementation
Shared FreeBSD power-source logic.
Factory for creating platform-specific FreeBsdPowerSource instances.
 
FreeBSD soundcard.
FreeBsd Usb Device
 
Reads from fstat and related utilities on NetBSD.
Reads from fstat.
Utility to query geom part list
Utility to query geom part list
The global configuration utility.
Indicates that a configuration value is invalid.
The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
GPU performance counter enums.
GPU Adapter Memory counter properties.
GPU Engine running time counter properties.
A session handle for sampling dynamic GPU metrics.
An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
Represents a graphics card (GPU) installed in the system.
The field or method to which this annotation is applied can only be accessed when holding a particular lock, which may be a built-in (synchronization) lock, or may be an explicit java.util.concurrent.Lock.
A hardware abstraction layer.
Base class for HKEY_PERFORMANCE_DATA utilities.
A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
Encapsulates network interface statistics read from the macOS NET_RT_IFLIST2 sysctl, shared between the JNA and FFM NetStat drivers.
The presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.
Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
Encapsulates information associated with an IP connection.
The TCP connection state as described in RFC 793.
Encapsulates statistics associated with a TCP connection.
Encapsulates statistics associated with a UDP connection.
Abstracts IOKit registry operations so that iteration logic can be shared between JNA and FFM implementations.
A handle to an IORegistry entry, providing property access.
Utility to query iostat
Constants, property enums, and WHERE clause builders for LibreHardwareMonitor WMI sensor data.
LHM Hardware properties.
Sensor properties returned by LHM WMI queries.
Linux Bluetooth device enumeration via BlueZ filesystem paths.
A CPU as defined in Linux /proc.
Native-free Linux central processor implementation.
Linux implementation of CgroupInfo supporting both cgroup v2 and v1.
The Linux File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Native-free Linux file system implementation.
Memory obtained by /proc/meminfo and sysinfo.totalram
Linux GpuStats session.
Graphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.
Parsed graphics card attributes used to construct concrete subclass instances.
LinuxHardwareAbstractionLayer class.
Native-free hardware abstraction layer for Linux.
Linux hard disk implementation.
Field ordering in udev stat output.
Native-free Linux disk store implementation.
Utility class for querying installed applications on Linux.
Internet Protocol Stats implementation
Linux implementation of LogicalVolumeGroup.
LinuxNetworks class.
Native-free Linux network interface implementation.
Linux network parameters.
Native-free Linux network parameters implementation.
Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.
Native-free Linux operating system implementation.
OSFileStore implementation
OSProcess implementation
Native-free Linux OS process implementation.
OSThread implementation
A Power Source
Power supply uevent properties from sysfs.
Linux USB device base class.
Native-free Linux USB device enumeration from /sys/bus/usb/devices/.
Utility to calculate a load average equivalent metric on Windows.
A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
Utility to parse printer information from lpstat and lpoptions commands.
Native-free CUPS printer implementation.
Utility to query ls
Utility to query lscfg
Utility to query lshal
Utility to read info from lshal
Utility to read info from lshw
Utility to query lspv
Utility to query lssrad
Baseboard data obtained from ioreg
macOS Bluetooth device enumeration via system_profiler SPBluetoothDataType.
Base class for macOS CentralProcessor implementations.
Hardware data obtained from ioreg.
Common constants and configuration for macOS file system implementations.
Firmware data obtained from ioreg.
Memory obtained by host_statistics (vm_stat) and sysctl.
Graphics card info obtained by system_profiler SPDisplaysDataType.
Factory for creating GraphicsCard instances.
Functional interface for sysctl long queries.
MacHardwareAbstractionLayer class.
Base class for macOS HWDiskStore implementations.
Strings to convert to CFStringRef for pointer lookups.
Utility class for querying installed applications on macOS.
Abstract base for the macOS InternetProtocolStats.
Selected fields of the macOS ip6stat structure.
Selected fields of the macOS ipstat structure.
Selected fields of the macOS tcpstat structure.
Selected fields of the macOS udpstat structure.
MacLogicalVolumeGroup class.
Base class for macOS NetworkIF implementations.
macOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.
Common base class for macOS OSFileStore implementations.
Abstract base shared by the macOS OSProcess implementations (JNA and FFM).
OSThread implementation
Abstract base for the macOS PowerSource.
Raw values read from a single IOKit Power Source (IOPS) dictionary by the JNA/FFM subclasses.
Creates a concrete (JNA or FFM) Mac power source from the computed battery fields.
Sound card data obtained via AppleHDA kext
Mac USB device base class.
Memory obtained by host_statistics (vm_stat) and sysctl.
A memoized function stores the output corresponding to some set of specific inputs.
Memory performance counter enums
For pages in/out
Utility to query mount
Constants and property enum for WMI class MSAcpi_ThermalZoneTemperature.
Current temperature property.
Constants and property enums for WMI classes in the Storage namespace associated with Storage Pools.
Properties for a physical disk.
Properties to identify the storage pool.
Properties to link a storage pool with a physical disk.
Properties for a virtual disk.
NetBSD Central Processor implementation.
NetBSD ComputerSystem implementation
The NetBSD File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
NetBSD Firmware implementation
NetBsdHardwareAbstractionLayer class.
NetBSD hard disk implementation.
Internet Protocol Stats implementation
NetBSD-specific NetworkIF implementation.
NetBsdNetworkParams class.
NetBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.
OSFileStore implementation
OSProcess implementation
OSThread implementation
Provides access to sysctl calls on NetBSD via command-line execution.
Utility to query TCP connections
A network interface in the machine, including statistics.
The current operational state of a network interface.
Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
A no-op GpuStats implementation returned by platforms that do not support a native stats session.
The presence of this annotation indicates that the author believes the class is not thread-safe.
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Hardware data.
HW Identifier Property.
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Sensor data.
Sensor value property.
Shared OpenBSD CentralProcessor logic.
 
OpenBSD Firmware implementation
 
Shared OpenBSD HWDiskStore logic.
Factory for creating platform-specific OpenBsdHWDiskStore instances.
Internet Protocol Stats implementation
OpenBsdNetworkParams class.
Abstract base shared by the OpenBSD OperatingSystem implementations (JNA and FFM).
OSFileStore implementation.
 
OSThread implementation
Memory info on OpenBSD
An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
A class representing the Operating System version details.
This class encapsulates information about a window on the operating system's GUI desktop.
A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Represents a Process on the operating system, which may contain multiple threads.
Process and Thread Execution States
Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
Service Execution States
This class encapsulates information about users who are currently logged in to an operating system.
Represents a Thread/Task on the operating system.
Constants which may be used to filter Thread lists
Paging File performance counter enums
For swap file usage
Convenience class for returning multiple objects from methods.
String parsing utility.
Contract for Counter Property Enums.
Contract for Wildcard Counter Property Enums.
Encapsulates the three string components of a PDH performance counter path, plus whether it refers to the base (SecondValue) of a multi-value counter.
Common interface for querying Windows performance counters, abstracting JNA and FFM implementations.
Constants used in Perfmon driver classes
Physical Disk performance counter enums
Physical Disk performance counters.
The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
An enumeration of supported operating systems.
A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
Units of Battery Capacity
Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
Printer status enumeration.
Utility class for privileged command execution and file reading.
Process performance counter enums
Handle performance counters
Processor performance counters
Process performance counters
Processor performance counter enums
System interrupts counters
Processor Frequency counters.
Processor Performance counters from the WMI Formatted Data table.
Processor performance counters
Processor performance counters including utility counters
System performance counters
Encapsulates process performance data from the registry performance counter block.
Common logic for building process performance data maps from registry or performance counter results.
Utility to read process statistics from /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/statm
Provides constants for paths in the /proc filesystem on Linux.
Provides process information on DragonFlyBSD using /proc and fstat
Reads from procstat into a map
Utility class for parsing /proc filesystem statistics.
Utility to query iostat
Shared utility to query the pure-Java parts of AIX /proc/<pid>/psinfo and /proc/<pid>/lwp/<tid>/lwpsinfo.
Shared utility to parse the pure-Java parts of Solaris /proc/<pid>/psinfo, /proc/<pid>/lwp/<tid>/lwpsinfo, and /proc/<pid>/usage.
Indicates that the annotated type is part of the OSHI public API.
Convenience class for returning multiple objects from methods.
Convenience class for returning multiple objects from methods.
Sensors include hardware sensors to monitor temperature, fan speed, and other information.
Abstract base for the Solaris CPU.
Hardware data obtained from smbios.
 
The Solaris File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Firmware data.
Memory obtained by kstat.
Graphics Card info obtained from prtconf
Abstract base for Solaris HWDiskStore.
Per-disk I/O stats the Solaris HAL reads.
Creates a concrete (JNA or FFM) Solaris disk store.
Internet Protocol Stats implementation
Pure-Java mirror of the Solaris lwpsinfo_t struct populated from /proc/<pid>/lwp/<tid>/lwpsinfo.
Abstract base for Solaris NetworkIF.
Per-interface stats the Solaris HAL reads.
Creates a concrete (JNA or FFM) Solaris network interface.
Abstract base for Solaris NetworkParams.
Solaris is a non-free Unix operating system originally developed by Sun Microsystems.
OSFileStore implementation for Solaris.
Abstract base for Solaris OSProcess.
Abstract base for Solaris OSThread.
Abstract base for the Solaris PowerSource.
Raw values read from the battery BIF0 (info) and battery BST0 (state) kstats.
Creates a concrete (JNA or FFM) Solaris power source from the computed battery fields.
Pure-Java mirror of the Solaris prusage_t struct populated from /proc/<pid>/usage or /proc/<pid>/lwp/<tid>/usage.
Pure-Java mirror of the Solaris psinfo_t struct populated from /proc/<pid>/psinfo.
Sensors from prtpicl
Solaris Sound Card.
64-bit Solaris timestruc_t: seconds and nanoseconds, each 8 bytes.
Solaris Usb Device
Memory obtained by kstat and swap
Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
This annotation exists to permit suppression in the Forbidden APIs check and also indicate to consumers of these classes that they may need to handle these differently in their production code.
Abstracts sysctl operations so that Mac base classes can query sysctl values without depending on JNA or FFM directly.
Utility to read info from sysfs
Provides constants for paths in the /sys filesystem on Linux.
Utility class parsing output from the BSD systat -ab sensors command, shared by OpenBSD and NetBSD which produce the same output format.
Immutable holder for battery sensor readings parsed from systat -ab sensors.
Native-free SystemInfoProvider for Linux.
Factory that uses ServiceLoader to discover and select the best available SystemInfoProvider.
Static helper methods for printing OSHI system information, shared across test modules.
Service Provider Interface for OSHI's SystemInfo entry points.
System performance counter enums
Context switch property
Processor Queue Length property
Utility to query threads for a process
Class to encapsulate mach thread info
Thread performance counter enums
Thread performance counters
Encapsulates thread performance data from the registry performance counter block.
Common logic for building thread performance data maps from registry or performance counter results.
The presence of this annotation indicates that the author believes the class to be thread-safe.
64-bit AIX timestruc_t required by the AixPsInfo struct: seconds, nanoseconds, padding.
Convenience class for returning multiple objects from methods.
Baseboard data obtained by a calling class
A Display
Utility to query up time.
Utility to read system uptime from /proc/uptime
A USB device is a device connected via a USB port, possibly internally/permanently.
Utility class to temporarily cache the userID and group maps in *nix, for parsing process ownership.
General utility methods
The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
Utility to query logged in users.
Utility to query logged in users using the who command with Linux date format parsing, falling back to Unix format.
Utility to query logged in users using the who command with Unix date format parsing.
Constants and property enum for WMI class Win32_BaseBoard.
Baseboard description properties.
Constants and property enums for WMI class Win32_BIOS.
BIOS description properties.
Serial number property.
Constants and property enum for WMI class Win32_ComputerSystem.
Computer System properties.
Constants and property enum for WMI class Win32_ComputerSystemProduct.
Computer System ID number.
Constants and property enum for WMI class Win32_DiskDrive.
Disk drive properties.
Constants and property enum for WMI class Win32_DiskDriveToDiskPartition.
Links disk drives to partitions.
Constants and property enum for WMI class Win32_DiskPartition.
Disk partition properties.
Constants and property enum for WMI class Win32_Fan.
Fan speed property.
Constants and property enum for WMI class Win32_LogicalDisk.
Logical disk properties.
Constants and property enum for WMI class Win32_LogicalDiskToPartition.
Links disk drives to partitions.
Constants and property enum for WMI class Win32_OperatingSystem.
Operating System properties.
Constants and property enums for WMI class Win32_PhysicalMemory.
Physical Memory properties for Win10 and later.
Physical Memory properties for Win8 and earlier.
Constants and property enum for WMI class Win32_Printer.
Printer properties from WMI.
Constants, property enums, and WHERE clause builder for WMI class Win32_Process.
Process command lines.
Process properties accessible from WTSEnumerateProcesses in Vista+.
Constants and property enums for WMI class Win32_Processor.
Processor bitness property.
Processor ID property.
Processor voltage properties.
Constants and property enum for WMI class Win32_VideoController.
Video Controller properties.
Baseboard data obtained from WMI.
Common non-native logic for Windows Central Processor implementations.
Hardware data obtained from WMI.
Firmware data obtained from WMI.
Common Windows global memory logic shared between JNA and FFM implementations.
Common Windows GpuStats implementation.
Common Windows hard disk implementation shared between JNA and FFM.
Maps to store read/write bytes per drive index
Maps for the partition structure
Common base class for Windows operating system implementations.
Common base class for Windows OSFileStore implementations.
Common base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.
Common base class for Windows OS thread implementations.
A Power Source
Common Windows printer logic shared between JNA and FFM implementations.
Abstract base shared by the Windows Sensors implementations (JNA and FFM).
WMI type constants used for interpreting WmiResult values.
Encapsulates a WMI query with a namespace, class name, and property enum.
Common interface for executing WMI queries, abstracting JNA and FFM implementations.
Common interface for WMI query results, abstracting JNA and FFM implementations.
Helper class for extracting typed values from WmiResult objects.
Data holder for Windows Terminal Services (WTS) process information.
Utility to query xrandr
Utility to query X11 windows