Uses of Package
oshi.annotation.concurrent
Packages that use oshi.annotation.concurrent
Package
Description
Provides functions to query Mac info
Provides functions to query information on AIX
Provides parsing utilities for commands shared by BSD-derived platforms (e.g.
Provides parsing utilities for BSD disk-related commands (e.g.
Provides functions to query FreeBSD disk information
Provides functions to query information on Solaris
Provides functions to query Solaris disk information.
Shared GPU-related driver classes for Windows, containing POJOs and utility methods with no native dependencies.
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides shared abstract base classes for the
/proc-filesystem Unix operating systemsProvides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides utilities for parsing, formatting, and other access
Provides utilities for DragonFly BSD
Shared, native-free FreeBSD utility classes (procstat parsing, etc.) used by both JNA and FFM implementations.
Provides utilities for NetBSD
Provides pure-Java utility classes for OpenBSD, shared by the JNA and FFM modules.
Provides non-native Linux driver utilities for querying system information.
Provides non-native Linux driver utilities for querying the
/proc filesystem.Provides driver utilities common to unix systems that do not require native access
Provides constants for Linux filesystem paths (
/proc, /dev, /sys).Provides classes encapsulating multiple objects, intended as return types from methods
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.bsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.bsd.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.freebsd.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.unix.solaris.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.gpuClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.perfmonClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.registryClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.wmiClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardwareClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.commonClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.linux.nativefreeClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unix.netbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.commonClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.linux.nativefreeClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.bsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.dragonflybsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.netbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.osClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.utilClassDescriptionThe presence of this annotation indicates that the author believes the class is not thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.common.platform.unix.dragonflybsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.common.platform.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.common.platform.unix.netbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.common.platform.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.linux.procClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.tuplesClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.