Uses of Package
oshi.annotation
Packages that use oshi.annotation
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access
-
Classes in oshi.annotation used by oshi.hardware
-
Classes in oshi.annotation used by oshi.software.os
-
Classes in oshi.annotation used by oshi.spi
-
Classes in oshi.annotation used by oshi.utilClassDescriptionIndicates that the annotated type is part of the OSHI public API.This annotation exists to permit suppression in the Forbidden APIs check and also indicate to consumers of these classes that they may need to handle these differently in their production code.