Enum Class ProcessInformation.ProcessPerformanceProperty
java.lang.Object
java.lang.Enum<ProcessInformation.ProcessPerformanceProperty>
oshi.driver.common.windows.perfmon.ProcessInformation.ProcessPerformanceProperty
- All Implemented Interfaces:
Serializable, Comparable<ProcessInformation.ProcessPerformanceProperty>, Constable, PdhCounterWildcardProperty
- Enclosing class:
ProcessInformation
public static enum ProcessInformation.ProcessPerformanceProperty
extends Enum<ProcessInformation.ProcessPerformanceProperty>
implements PdhCounterWildcardProperty
Process performance counters
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionCreating process ID.Process elapsed time.Process ID.I/O read bytes per second.I/O write bytes per second.Instance filter (not _Total).Page faults per second.Process priority base.Working set bytes.Working set private bytes. -
Method Summary
Modifier and TypeMethodDescriptionGets the counter name for this property.Returns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
NAME
Instance filter (not _Total). -
PRIORITYBASE
Process priority base. -
ELAPSEDTIME
Process elapsed time. -
IDPROCESS
Process ID. -
CREATINGPROCESSID
Creating process ID. -
IOREADBYTESPERSEC
I/O read bytes per second. -
IOWRITEBYTESPERSEC
I/O write bytes per second. -
WORKINGSETPRIVATE
Working set private bytes. -
WORKINGSET
Working set bytes. -
PAGEFAULTSPERSEC
Page faults per second.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getCounter
Description copied from interface:PdhCounterWildcardPropertyGets the counter name for this property.- Specified by:
getCounterin interfacePdhCounterWildcardProperty- Returns:
- Returns the counter. The first element of the enum will return the instance filter rather than a counter.
-