Enum Class ProcessorInformation.ProcessorPerformanceProperty
java.lang.Object
java.lang.Enum<ProcessorInformation.ProcessorPerformanceProperty>
oshi.driver.common.windows.perfmon.ProcessorInformation.ProcessorPerformanceProperty
- All Implemented Interfaces:
Serializable, Comparable<ProcessorInformation.ProcessorPerformanceProperty>, Constable, PdhCounterWildcardProperty
- Enclosing class:
ProcessorInformation
public static enum ProcessorInformation.ProcessorPerformanceProperty
extends Enum<ProcessorInformation.ProcessorPerformanceProperty>
implements PdhCounterWildcardProperty
Processor Performance counters from the WMI Formatted Data table. Reports above 100% with turbo boost. Requires
Win8 or greater.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionInstance filter (not _Total).Percent processor performance (can exceed 100% with turbo). -
Method Summary
Modifier and TypeMethodDescriptionGets the counter name for this property.Returns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
NAME
Instance filter (not _Total). -
PERCENTPROCESSORPERFORMANCE
Percent processor performance (can exceed 100% with turbo).
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getCounter
Description copied from interface:PdhCounterWildcardPropertyGets the counter name for this property.- Specified by:
getCounterin interfacePdhCounterWildcardProperty- Returns:
- Returns the counter. The first element of the enum will return the instance filter rather than a counter.
-