Class ThreadInformation
java.lang.Object
oshi.driver.common.windows.perfmon.ThreadInformation
Thread performance counter enums
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic enumThread performance counters -
Method Summary
Modifier and TypeMethodDescriptionqueryThreadCounters(PerfCounterQueryExecutor executor) Returns thread counters for all threads.queryThreadCounters(PerfCounterQueryExecutor executor, String name, int threadNum) Returns thread counters filtered to the specified process name and thread.
-
Method Details
-
queryThreadCounters
public static Pair<List<String>, Map<ThreadInformation.ThreadPerformanceProperty, List<Long>>> queryThreadCounters(PerfCounterQueryExecutor executor) Returns thread counters for all threads.- Parameters:
executor- the performance counter query executor- Returns:
- Thread counters for each thread.
-
queryThreadCounters
public static Pair<List<String>, Map<ThreadInformation.ThreadPerformanceProperty, List<Long>>> queryThreadCounters(PerfCounterQueryExecutor executor, String name, int threadNum) Returns thread counters filtered to the specified process name and thread.- Parameters:
executor- the performance counter query executorname- The process name to filterthreadNum- The thread number to match. -1 matches all threads.- Returns:
- Thread counters for each thread.
-