Uses of Interface
oshi.driver.common.windows.perfmon.PerfCounterQueryExecutor
Packages that use PerfCounterQueryExecutor
Package
Description
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
-
Uses of PerfCounterQueryExecutor in oshi.driver.common.windows.perfmon
Methods in oshi.driver.common.windows.perfmon with parameters of type PerfCounterQueryExecutorModifier and TypeMethodDescriptionSystemInformation.queryContextSwitchCounters(PerfCounterQueryExecutor executor) Returns context switch counters.PhysicalDisk.queryDiskCounters(PerfCounterQueryExecutor executor) Returns physical disk performance counters.ProcessorInformation.queryFrequencyCounters(PerfCounterQueryExecutor executor) Returns processor frequency counters.GpuInformation.queryGpuAdapterMemoryCounters(PerfCounterQueryExecutor executor) Queries GPU Adapter Memory counters for all instances.GpuInformation.queryGpuEngineCounters(PerfCounterQueryExecutor executor) Queries GPU Engine counters for all instances.ProcessInformation.queryHandles(PerfCounterQueryExecutor executor) Returns handle count.ProcessInformation.queryIdleProcessCounters(PerfCounterQueryExecutor executor) Returns idle process counters (for load average calculation).ProcessorInformation.queryInterruptCounters(PerfCounterQueryExecutor executor) Returns system interrupts counters.static Map<MemoryInformation.PageSwapProperty, Long> MemoryInformation.queryPageSwaps(PerfCounterQueryExecutor executor) Returns page swap counters.ProcessInformation.queryProcessCounters(PerfCounterQueryExecutor executor) Returns process performance counters.ProcessorInformation.queryProcessorCapacityCounters(PerfCounterQueryExecutor executor) Returns processor capacity performance counters.ProcessorInformation.queryProcessorCounters(PerfCounterQueryExecutor executor) Returns processor performance counters.ProcessorInformation.queryProcessorPerformanceCounters(PerfCounterQueryExecutor executor) Returns processor performance percentage (cooked) from the WMI Formatted Data table.SystemInformation.queryProcessorQueueLength(PerfCounterQueryExecutor executor) Returns processor queue length.static Map<PagingFile.PagingPercentProperty, Long> PagingFile.querySwapUsed(PerfCounterQueryExecutor executor) Returns paging file usage counters.ProcessorInformation.querySystemCounters(PerfCounterQueryExecutor executor) Returns system performance counters.ThreadInformation.queryThreadCounters(PerfCounterQueryExecutor executor) Returns thread counters for all threads.ThreadInformation.queryThreadCounters(PerfCounterQueryExecutor executor, String name, int threadNum) Returns thread counters filtered to the specified process name and thread.