Uses of Enum Class
oshi.driver.common.windows.perfmon.ProcessInformation.ProcessPerformanceProperty
Packages that use ProcessInformation.ProcessPerformanceProperty
Package
Description
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
-
Uses of ProcessInformation.ProcessPerformanceProperty in oshi.driver.common.windows.perfmon
Subclasses with type arguments of type ProcessInformation.ProcessPerformanceProperty in oshi.driver.common.windows.perfmonModifier and TypeClassDescriptionstatic enumProcess performance countersMethods in oshi.driver.common.windows.perfmon that return ProcessInformation.ProcessPerformancePropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.ProcessInformation.ProcessPerformanceProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.perfmon that return types with arguments of type ProcessInformation.ProcessPerformancePropertyModifier and TypeMethodDescriptionProcessInformation.queryProcessCounters(PerfCounterQueryExecutor executor) Returns process performance counters. -
Uses of ProcessInformation.ProcessPerformanceProperty in oshi.driver.common.windows.registry
Method parameters in oshi.driver.common.windows.registry with type arguments of type ProcessInformation.ProcessPerformancePropertyModifier and TypeMethodDescriptionstatic Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceData.buildProcessMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ProcessInformation.ProcessPerformanceProperty, List<Long>>> instanceValues) Builds a process map from performance counter query results.static Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceData.buildProcessMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ProcessInformation.ProcessPerformanceProperty, Object>>, Long, Long> processData) Builds a process map from registry performance data that has already been read.