Uses of Enum Class
oshi.driver.common.windows.perfmon.ThreadInformation.ThreadPerformanceProperty
Packages that use ThreadInformation.ThreadPerformanceProperty
Package
Description
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
-
Uses of ThreadInformation.ThreadPerformanceProperty in oshi.driver.common.windows.perfmon
Subclasses with type arguments of type ThreadInformation.ThreadPerformanceProperty in oshi.driver.common.windows.perfmonModifier and TypeClassDescriptionstatic enumThread performance countersMethods in oshi.driver.common.windows.perfmon that return ThreadInformation.ThreadPerformancePropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.ThreadInformation.ThreadPerformanceProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.perfmon that return types with arguments of type ThreadInformation.ThreadPerformancePropertyModifier and TypeMethodDescriptionThreadInformation.queryThreadCounters(PerfCounterQueryExecutor executor) Returns thread counters for all threads.ThreadInformation.queryThreadCounters(PerfCounterQueryExecutor executor, String name, int threadNum) Returns thread counters filtered to the specified process name and thread. -
Uses of ThreadInformation.ThreadPerformanceProperty in oshi.driver.common.windows.registry
Method parameters in oshi.driver.common.windows.registry with type arguments of type ThreadInformation.ThreadPerformancePropertyModifier and TypeMethodDescriptionstatic Map<Integer, ThreadPerfCounterBlock> ThreadPerformanceData.buildThreadMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ThreadInformation.ThreadPerformanceProperty, List<Long>>> instanceValues) Builds a thread map from performance counter query results.static Map<Integer, ThreadPerfCounterBlock> ThreadPerformanceData.buildThreadMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ThreadInformation.ThreadPerformanceProperty, Object>>, Long, Long> threadData) Builds a thread map from registry performance data that has already been read.