Uses of Class
oshi.driver.common.windows.registry.ThreadPerfCounterBlock
Packages that use ThreadPerfCounterBlock
Package
Description
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Uses of ThreadPerfCounterBlock in oshi.driver.common.windows.registry
Methods in oshi.driver.common.windows.registry that return types with arguments of type ThreadPerfCounterBlockModifier and TypeMethodDescriptionstatic Map<Integer, ThreadPerfCounterBlock> ThreadPerformanceData.buildThreadMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ThreadInformation.ThreadPerformanceProperty, List<Long>>> instanceValues) Builds a thread map from performance counter query results.static Map<Integer, ThreadPerfCounterBlock> ThreadPerformanceData.buildThreadMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ThreadInformation.ThreadPerformanceProperty, Object>>, Long, Long> threadData) Builds a thread map from registry performance data that has already been read. -
Uses of ThreadPerfCounterBlock in oshi.software.common.os.windows
Methods in oshi.software.common.os.windows that return types with arguments of type ThreadPerfCounterBlockModifier and TypeMethodDescriptionprotected abstract Map<Integer, ThreadPerfCounterBlock> WindowsOSProcess.queryMatchingThreads(Set<Integer> pids) Queries thread performance data matching the given process IDs.Methods in oshi.software.common.os.windows with parameters of type ThreadPerfCounterBlockModifier and TypeMethodDescriptionprotected abstract OSThreadWindowsOSProcess.createOSThread(int pid, int tid, String procName, ThreadPerfCounterBlock pcb) Creates a platform-specific OS thread instance.protected booleanWindowsOSThread.updateAttributes(String procName, ThreadPerfCounterBlock pcb) Updates thread attributes from a performance counter block.Method parameters in oshi.software.common.os.windows with type arguments of type ThreadPerfCounterBlockModifier and TypeMethodDescriptionprotected voidWindowsOSProcess.setTcb(Map<Integer, ThreadPerfCounterBlock> tcb) Sets the thread counter block map.Constructors in oshi.software.common.os.windows with parameters of type ThreadPerfCounterBlockModifierConstructorDescriptionprotectedWindowsOSThread(int pid, int tid, String procName, ThreadPerfCounterBlock pcb) Constructor.