Enum Class Win32ComputerSystem.ComputerSystemProperty
java.lang.Object
java.lang.Enum<Win32ComputerSystem.ComputerSystemProperty>
oshi.driver.common.windows.wmi.Win32ComputerSystem.ComputerSystemProperty
- All Implemented Interfaces:
Serializable, Comparable<Win32ComputerSystem.ComputerSystemProperty>, Constable
- Enclosing class:
Win32ComputerSystem
public static enum Win32ComputerSystem.ComputerSystemProperty
extends Enum<Win32ComputerSystem.ComputerSystemProperty>
Computer System properties.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
MANUFACTURER
MANUFACTURER property. -
MODEL
MODEL property.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-