Enum Class Win32OperatingSystem.OSVersionProperty
java.lang.Object
java.lang.Enum<Win32OperatingSystem.OSVersionProperty>
oshi.driver.common.windows.wmi.Win32OperatingSystem.OSVersionProperty
- All Implemented Interfaces:
Serializable, Comparable<Win32OperatingSystem.OSVersionProperty>, Constable
- Enclosing class:
Win32OperatingSystem
public static enum Win32OperatingSystem.OSVersionProperty
extends Enum<Win32OperatingSystem.OSVersionProperty>
Operating System properties.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionBUILDNUMBER property.CSDVERSION property.PRODUCTTYPE property.SUITEMASK property.VERSION property. -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
VERSION
VERSION property. -
PRODUCTTYPE
PRODUCTTYPE property. -
BUILDNUMBER
BUILDNUMBER property. -
CSDVERSION
CSDVERSION property. -
SUITEMASK
SUITEMASK property.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-