Uses of Enum
oshi.driver.common.windows.wmi.Win32ComputerSystem.ComputerSystemProperty
Packages that use Win32ComputerSystem.ComputerSystemProperty
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
-
Uses of Win32ComputerSystem.ComputerSystemProperty in oshi.driver.common.windows.wmi
Subclasses with type arguments of type Win32ComputerSystem.ComputerSystemProperty in oshi.driver.common.windows.wmiModifier and TypeClassDescriptionstatic enumComputer System properties.Methods in oshi.driver.common.windows.wmi that return Win32ComputerSystem.ComputerSystemPropertyModifier and TypeMethodDescriptionReturns the enum constant of this type with the specified name.Win32ComputerSystem.ComputerSystemProperty.values()Returns an array containing the constants of this enum type, in the order they are declared.