Uses of Enum Class
oshi.driver.common.windows.wmi.Win32OperatingSystem.OSVersionProperty
Packages that use Win32OperatingSystem.OSVersionProperty
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
-
Uses of Win32OperatingSystem.OSVersionProperty in oshi.driver.common.windows.wmi
Subclasses with type arguments of type Win32OperatingSystem.OSVersionProperty in oshi.driver.common.windows.wmiModifier and TypeClassDescriptionstatic enumOperating System properties.Methods in oshi.driver.common.windows.wmi that return Win32OperatingSystem.OSVersionPropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.Win32OperatingSystem.OSVersionProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.wmi that return types with arguments of type Win32OperatingSystem.OSVersionPropertyModifier and TypeMethodDescriptionWin32OperatingSystem.queryOsVersion(WmiQueryExecutor h) Queries the operating system version.