Uses of Interface
oshi.driver.common.windows.wmi.WmiQueryExecutor
Packages that use WmiQueryExecutor
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of WmiQueryExecutor in oshi.driver.common.windows.wmi
Methods in oshi.driver.common.windows.wmi that return WmiQueryExecutorModifier and TypeMethodDescriptionstatic WmiQueryExecutorWmiQueryExecutor.createInstance()Creates a new instance of the platform-appropriate WMI query executor.Methods in oshi.driver.common.windows.wmi with parameters of type WmiQueryExecutorModifier and TypeMethodDescriptionWin32BaseBoard.queryBaseboardInfo(WmiQueryExecutor h) Queries baseboard information.static WmiResult<Win32Bios.BiosProperty> Win32Bios.queryBiosInfo(WmiQueryExecutor h) Queries the BIOS description.Win32Processor.queryBitness(WmiQueryExecutor h) Queries processor bitness.Win32Process.queryCommandLines(WmiQueryExecutor h, Set<Integer> pidsToQuery) Returns process command lines.Win32ComputerSystem.queryComputerSystem(WmiQueryExecutor h) Queries computer system information.MSAcpiThermalZoneTemperature.queryCurrentTemperature(WmiQueryExecutor h) Queries current temperature from thermal zone.Win32DiskDrive.queryDiskDrive(WmiQueryExecutor h) Queries disk drive information.Win32LogicalDiskToPartition.queryDiskToPartition(WmiQueryExecutor h) Queries logical disk to partition mapping.Win32DiskDriveToDiskPartition.queryDriveToPartition(WmiQueryExecutor h) Queries disk drive to partition mapping.LhmSensor.queryGpuHardware(WmiQueryExecutor h) Queries all GPU hardware entries from LHM to discover parent identifiers.OhmHardware.queryHwIdentifier(WmiQueryExecutor h, String typeToQuery, String typeName) Queries the hardware identifiers for a monitored type.Win32ComputerSystemProduct.queryIdentifyingNumberUUID(WmiQueryExecutor h) Queries the UUID and identifying number.Win32LogicalDisk.queryLogicalDisk(WmiQueryExecutor h, String nameToMatch, boolean localOnly) Queries logical disk information.Win32OperatingSystem.queryOsVersion(WmiQueryExecutor h) Queries the operating system version.Win32DiskPartition.queryPartition(WmiQueryExecutor h) Queries disk partition information.MSFTStorage.queryPhysicalDisks(WmiQueryExecutor h) Queries physical disks.Win32PhysicalMemory.queryPhysicalMemory(WmiQueryExecutor h) Queries physical memory information.Win32PhysicalMemory.queryPhysicalMemoryWin8(WmiQueryExecutor h) Queries physical memory information (Win8+ properties).Win32Printer.queryPrinters(WmiQueryExecutor h) Queries printer information.Win32Process.queryProcesses(WmiQueryExecutor h, Collection<Integer> pids) Returns process info.Win32Processor.queryProcessorId(WmiQueryExecutor h) Queries processor ID.static WmiResult<LhmSensor.LhmSensorProperty> LhmSensor.querySensors(WmiQueryExecutor h, String parent, String sensorType) Queries all sensors of a given type belonging to a specific hardware parent.static WmiResult<OhmSensor.ValueProperty> OhmSensor.querySensorValue(WmiQueryExecutor h, String identifier, String sensorType) Queries the sensor value of a hardware identifier and sensor type.Win32Bios.querySerialNumber(WmiQueryExecutor h) Queries the BIOS serial number.static WmiResult<Win32Fan.SpeedProperty> Win32Fan.querySpeed(WmiQueryExecutor h) Queries fan speed.MSFTStorage.queryStoragePoolPhysicalDisks(WmiQueryExecutor h) Queries storage pool to physical disk mapping.MSFTStorage.queryStoragePools(WmiQueryExecutor h) Queries storage pools.Win32VideoController.queryVideoController(WmiQueryExecutor h) Queries video controller information.MSFTStorage.queryVirtualDisks(WmiQueryExecutor h) Queries virtual disks.static WmiResult<Win32Processor.VoltProperty> Win32Processor.queryVoltage(WmiQueryExecutor h) Queries processor voltage. -
Uses of WmiQueryExecutor in oshi.hardware.common.platform.windows
Methods in oshi.hardware.common.platform.windows that return WmiQueryExecutorModifier and TypeMethodDescriptionprotected abstract WmiQueryExecutorWindowsBaseboard.getWmiQueryExecutor()Returns the WMI query executor for this platform.protected abstract WmiQueryExecutorWindowsComputerSystem.getWmiQueryExecutor()Returns the WMI query executor for this platform.protected abstract WmiQueryExecutorWindowsFirmware.getWmiQueryExecutor()Returns the WMI query executor for this platform.