Enum Class PowerSource.CapacityUnits

java.lang.Object
java.lang.Enum<PowerSource.CapacityUnits>
oshi.hardware.PowerSource.CapacityUnits
All Implemented Interfaces:
Serializable, Comparable<PowerSource.CapacityUnits>, Constable
Enclosing interface:
PowerSource

@PublicApi public static enum PowerSource.CapacityUnits extends Enum<PowerSource.CapacityUnits>
Units of Battery Capacity
  • Enum Constant Details

    • MWH

      public static final PowerSource.CapacityUnits MWH
      MilliWattHours (mWh).
    • MAH

      public static final PowerSource.CapacityUnits MAH
      MilliAmpHours (mAh). Should be multiplied by voltage to convert to mWh.
    • RELATIVE

      public static final PowerSource.CapacityUnits RELATIVE
      Relative units. The specific units are not defined. The ratio of current/max capacity still represents state of charge and the ratio of max/design capacity still represents state of health.
  • Method Details

    • values

      public static PowerSource.CapacityUnits[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static PowerSource.CapacityUnits valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null