Enum Class Printer.PrinterStatus
- All Implemented Interfaces:
Serializable, Comparable<Printer.PrinterStatus>, Constable
- Enclosing interface:
Printer
Printer status enumeration.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionstatic Printer.PrinterStatusReturns the enum constant of this class with the specified name.static Printer.PrinterStatus[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
IDLE
Printer is idle. -
PRINTING
Printer is printing. -
ERROR
Printer has an error. -
OFFLINE
Printer is offline. -
UNKNOWN
Printer status is unknown.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-