Uses of Interface
oshi.hardware.BluetoothDevice
Packages that use BluetoothDevice
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
-
Uses of BluetoothDevice in oshi.hardware
Methods in oshi.hardware that return types with arguments of type BluetoothDeviceModifier and TypeMethodDescriptiondefault List<BluetoothDevice> HardwareAbstractionLayer.getBluetoothDevices()Instantiates a list ofBluetoothDeviceobjects, representing Bluetooth devices (paired or connected) known to the system. -
Uses of BluetoothDevice in oshi.hardware.common
Classes in oshi.hardware.common that implement BluetoothDeviceModifier and TypeClassDescriptionclassAbstract base class for BluetoothDevice implementations. -
Uses of BluetoothDevice in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement BluetoothDeviceModifier and TypeClassDescriptionfinal classLinux Bluetooth device enumeration via BlueZ filesystem paths.Methods in oshi.hardware.common.platform.linux that return types with arguments of type BluetoothDeviceModifier and TypeMethodDescriptionstatic List<BluetoothDevice> LinuxBluetoothDevice.getBluetoothDevices()Gets Bluetooth devices known to the system.LinuxHardwareAbstractionLayer.getBluetoothDevices() -
Uses of BluetoothDevice in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement BluetoothDeviceModifier and TypeClassDescriptionfinal classmacOS Bluetooth device enumeration viasystem_profiler SPBluetoothDataType.Methods in oshi.hardware.common.platform.mac that return types with arguments of type BluetoothDeviceModifier and TypeMethodDescriptionstatic List<BluetoothDevice> MacBluetoothDevice.getBluetoothDevices()Gets Bluetooth devices known to the system.MacHardwareAbstractionLayer.getBluetoothDevices()