Uses of Class
oshi.hardware.CentralProcessor.LogicalProcessor
Packages that use CentralProcessor.LogicalProcessor
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of CentralProcessor.LogicalProcessor in oshi.hardware
Methods in oshi.hardware that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionCentralProcessor.getLogicalProcessors()Returns anUnmodifiableListof the CPU's logical processors. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common
Methods in oshi.hardware.common that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionAbstractCentralProcessor.getLogicalProcessors()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AbstractCentralProcessor.initProcessorCounts()Initializes logical and physical processor lists and feature flags.Method parameters in oshi.hardware.common with type arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected List<CentralProcessor.PhysicalProcessor> AbstractCentralProcessor.createProcListFromDmesg(List<CentralProcessor.LogicalProcessor> logProcs, Map<Integer, String> dmesg) Creates a list of physical processors from dmesg output. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected static CentralProcessor.LogicalProcessorLinuxCentralProcessor.getLogicalProcessorFromSyspath(String syspath, Set<CentralProcessor.ProcessorCache> caches, String modAlias, Map<Integer, Integer> coreEfficiencyMap, Map<Integer, String> modAliasMap) getLogicalProcessorFromSyspath.Methods in oshi.hardware.common.platform.linux that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> LinuxCentralProcessor.initProcessorCounts()protected static Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyFromSysfs()Reads processor topology from sysfs using the default CPU path.protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyWithUdev()Reads processor topology using udev. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessorNF.readTopologyWithUdev() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> MacCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.unix
Methods in oshi.hardware.common.platform.unix that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> BsdCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.unix.aix
Methods in oshi.hardware.common.platform.unix.aix that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AixCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.unix.freebsd
Methods in oshi.hardware.common.platform.unix.freebsd that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> FreeBsdCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.unix.solaris
Methods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> SolarisCentralProcessor.initProcessorCounts()protected abstract List<CentralProcessor.LogicalProcessor> SolarisCentralProcessor.queryLogicalProcessors()Enumerates the logical processors from the subclass's kstat data source. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.windows
Method parameters in oshi.hardware.common.platform.windows with type arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected voidWindowsCentralProcessor.buildNumaNodeProcMap(List<CentralProcessor.LogicalProcessor> logProcs) Builds the numaNodeProcToLogicalProcMap from the logical processor list.