Uses of Class
oshi.hardware.CentralProcessor.PhysicalProcessor
Packages that use CentralProcessor.PhysicalProcessor
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware
Methods in oshi.hardware that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionCentralProcessor.getPhysicalProcessors()Returns anUnmodifiableListof the CPU's physical processors. -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common
Methods in oshi.hardware.common that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected List<CentralProcessor.PhysicalProcessor> AbstractCentralProcessor.createProcListFromDmesg(List<CentralProcessor.LogicalProcessor> logProcs, Map<Integer, String> dmesg) Creates a list of physical processors from dmesg output.AbstractCentralProcessor.getPhysicalProcessors()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AbstractCentralProcessor.initProcessorCounts()Initializes logical and physical processor lists and feature flags. -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> LinuxCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> MacCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.unix
Methods in oshi.hardware.common.platform.unix that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> BsdCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.unix.aix
Methods in oshi.hardware.common.platform.unix.aix that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AixCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.unix.freebsd
Methods in oshi.hardware.common.platform.unix.freebsd that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> FreeBsdCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.unix.solaris
Methods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> SolarisCentralProcessor.initProcessorCounts()