Uses of Class
oshi.hardware.CentralProcessor.ProcessorCache

Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems