Uses of Class
oshi.hardware.CentralProcessor.ProcessorIdentifier
Packages that use CentralProcessor.ProcessorIdentifier
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
-
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware
Methods in oshi.hardware that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionCentralProcessor.getProcessorIdentifier()The CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU). -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common
Methods in oshi.hardware.common that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionAbstractCentralProcessor.getProcessorIdentifier()protected abstract CentralProcessor.ProcessorIdentifierAbstractCentralProcessor.queryProcessorId()Updates logical and physical processor counts and arrays -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierLinuxCentralProcessor.queryProcessorId() -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierMacCentralProcessor.queryProcessorId() -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.unix.aix
Methods in oshi.hardware.common.platform.unix.aix that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierAixCentralProcessor.queryProcessorId() -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.unix.freebsd
Methods in oshi.hardware.common.platform.unix.freebsd that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierFreeBsdCentralProcessor.queryProcessorId() -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.unix.netbsd
Methods in oshi.hardware.common.platform.unix.netbsd that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierNetBsdCentralProcessor.queryProcessorId() -
Uses of CentralProcessor.ProcessorIdentifier in oshi.hardware.common.platform.unix.openbsd
Methods in oshi.hardware.common.platform.unix.openbsd that return CentralProcessor.ProcessorIdentifierModifier and TypeMethodDescriptionprotected CentralProcessor.ProcessorIdentifierOpenBsdCentralProcessor.queryProcessorId()