Uses of Interface
oshi.hardware.ComputerSystem
Packages that use ComputerSystem
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides utilities for parsing, formatting, and other access
-
Uses of ComputerSystem in oshi.hardware
Methods in oshi.hardware that return ComputerSystemModifier and TypeMethodDescriptionHardwareAbstractionLayer.getComputerSystem()Instantiates aComputerSystemobject. -
Uses of ComputerSystem in oshi.hardware.common
Classes in oshi.hardware.common that implement ComputerSystemMethods in oshi.hardware.common that return ComputerSystemModifier and TypeMethodDescriptionprotected abstract ComputerSystemAbstractHardwareAbstractionLayer.createComputerSystem()Instantiates the platform-specificComputerSystemobjectAbstractHardwareAbstractionLayer.getComputerSystem() -
Uses of ComputerSystem in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return ComputerSystem -
Uses of ComputerSystem in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement ComputerSystem -
Uses of ComputerSystem in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement ComputerSystem -
Uses of ComputerSystem in oshi.util
Methods in oshi.util with parameters of type ComputerSystemModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printComputerSystem(List<String> lines, ComputerSystem computerSystem) Prints Computer System information to the output lines.