Uses of Interface
oshi.hardware.Display

Packages that use Display
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides common Unix hardware implementations shared by JNA and FFM modules.