Uses of Interface
oshi.hardware.DisplayInfo
Packages that use DisplayInfo
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides utilities for parsing, formatting, and other access
-
Uses of DisplayInfo in oshi.hardware
Classes in oshi.hardware that implement DisplayInfoMethods in oshi.hardware that return DisplayInfo -
Uses of DisplayInfo in oshi.hardware.common
Methods in oshi.hardware.common that return DisplayInfoConstructors in oshi.hardware.common with parameters of type DisplayInfoModifierConstructorDescriptionprotectedAbstractDisplay(DisplayInfo displayInfo) Constructor for AbstractDisplay from decoded display information, used when a display reports its attributes without providing an EDID. -
Uses of DisplayInfo in oshi.util
Methods in oshi.util that return DisplayInfoModifier and TypeMethodDescriptionstatic DisplayInfoEdidUtil.synthesizeDisplayInfo(Long legacyManufacturerId, Integer modelNumber, Integer serialNumber, Integer week, Integer year, String model, String productSerial, Long displayWidth, Long displayHeight, String fallbackName, Double screenWidthMm, Double screenHeightMm, String displayName) Builds a syntheticDisplayInfofrom individual display properties, for displays that report their attributes without providing an EDID (such as Apple Silicon built-in panels).