Uses of Interface
oshi.hardware.PowerSource
Packages that use PowerSource
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of PowerSource in oshi.hardware
Methods in oshi.hardware that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionHardwareAbstractionLayer.getPowerSources()Instantiates a list ofPowerSourceobjects, representing batteries, etc. -
Uses of PowerSource in oshi.hardware.common
Classes in oshi.hardware.common that implement PowerSourceMethods in oshi.hardware.common that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected abstract List<PowerSource> AbstractPowerSource.queryPowerSources()Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). -
Uses of PowerSource in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement PowerSourceMethods in oshi.hardware.common.platform.linux that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> LinuxPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> LinuxPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement PowerSourceMethods in oshi.hardware.common.platform.mac that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected static List<PowerSource> MacPowerSource.buildPowerSources(IOKitProvider ioKit, double timeRemainingEstimated, List<MacPowerSource.PowerSourceData> sources, MacPowerSource.PowerSourceFactory factory) Reads theAppleSmartBatteryregistry entry (viaioKit) and merges it with the per-source IOPS readings into a list of power sources. -
Uses of PowerSource in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement PowerSourceModifier and TypeClassDescriptionfinal classShared power-source implementation for BSDs that useapmandsystat -ab sensorsfor battery state (NetBSD, OpenBSD).Methods in oshi.hardware.common.platform.unix that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> BsdPowerSource.getPowerSources()Gets Battery Information.protected List<PowerSource> BsdPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.unix.aix
Classes in oshi.hardware.common.platform.unix.aix that implement PowerSourceMethods in oshi.hardware.common.platform.unix.aix that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> AixPowerSource.getPowerSources()Gets Battery Information.protected List<PowerSource> AixPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement PowerSourceMethods in oshi.hardware.common.platform.unix.freebsd that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected static <T extends FreeBsdPowerSource>
List<PowerSource> FreeBsdPowerSource.queryBattery(String name, BiFunction<String, Integer, Integer> sysctlInt, FreeBsdPowerSource.PowerSourceFactory<T> factory) Queries battery information and constructs a power source instance using the provided sysctl accessor and factory. -
Uses of PowerSource in oshi.hardware.common.platform.unix.netbsd
Methods in oshi.hardware.common.platform.unix.netbsd that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement PowerSourceModifier and TypeClassDescriptionclassAbstract base for the Solaris PowerSource.Methods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected static List<PowerSource> SolarisPowerSource.buildPowerSources(String name, SolarisPowerSource.BatteryReadings readings, SolarisPowerSource.PowerSourceFactory factory) Computes a single batteryPowerSourcefrom the given readings, building the concrete instance with the supplied factory. -
Uses of PowerSource in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement PowerSource