Uses of Interface
oshi.hardware.Printer
Packages that use Printer
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of Printer in oshi.hardware
Methods in oshi.hardware that return types with arguments of type PrinterModifier and TypeMethodDescriptionHardwareAbstractionLayer.getPrinters()Instantiates a list ofPrinterobjects, representing printers. -
Uses of Printer in oshi.hardware.common
Classes in oshi.hardware.common that implement PrinterModifier and TypeClassDescriptionclassAbstract base class for Printer implementations. -
Uses of Printer in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement PrinterModifier and TypeClassDescriptionclassCUPS-based printer implementation with shared lpstat fallback logic.final classNative-free CUPS printer implementation.Methods in oshi.hardware.common.platform.unix that return PrinterModifier and TypeMethodDescriptionCupsPrinter.PrinterFactory.create(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName) Create a printer instance.Methods in oshi.hardware.common.platform.unix that return types with arguments of type PrinterModifier and TypeMethodDescriptionLpstatPrinter.getPrinters()Gets the list of printers known to CUPS by parsinglpstat -poutput.CupsPrinter.getPrintersFromLpstat(CupsPrinter.PrinterFactory factory) Gets printers by parsing lpstat command output. -
Uses of Printer in oshi.hardware.common.platform.unix.netbsd
Methods in oshi.hardware.common.platform.unix.netbsd that return types with arguments of type Printer -
Uses of Printer in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement PrinterModifier and TypeClassDescriptionclassCommon Windows printer logic shared between JNA and FFM implementations.