Uses of Enum Class
oshi.hardware.Printer.PrinterStatus

Packages that use Printer.PrinterStatus
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides driver utilities common to unix systems that do not require native access