Uses of Interface
oshi.hardware.SoundCard
Packages that use SoundCard
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of SoundCard in oshi.hardware
Methods in oshi.hardware that return types with arguments of type SoundCardModifier and TypeMethodDescriptionHardwareAbstractionLayer.getSoundCards()Instantiates a list ofSoundCardobjects, representing the Sound cards. -
Uses of SoundCard in oshi.hardware.common
Classes in oshi.hardware.common that implement SoundCard -
Uses of SoundCard in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return types with arguments of type SoundCard -
Uses of SoundCard in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement SoundCardModifier and TypeClassDescriptionfinal classSound card data obtained via AppleHDA kextMethods in oshi.hardware.common.platform.mac that return types with arguments of type SoundCardModifier and TypeMethodDescriptionMacHardwareAbstractionLayer.getSoundCards()MacSoundCard.getSoundCards()public method used byAbstractHardwareAbstractionLayerto access the sound cards. -
Uses of SoundCard in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement SoundCardModifier and TypeClassDescriptionfinal classShared sound card implementation for BSDs that usedmesgaudio/pci patterns (NetBSD, OpenBSD).Methods in oshi.hardware.common.platform.unix that return types with arguments of type SoundCardModifier and TypeMethodDescriptionBsdSoundCard.getSoundCards()Gets sound cards by parsingdmesgoutput. -
Uses of SoundCard in oshi.hardware.common.platform.unix.aix
Classes in oshi.hardware.common.platform.unix.aix that implement SoundCardMethods in oshi.hardware.common.platform.unix.aix that return types with arguments of type SoundCard -
Uses of SoundCard in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement SoundCardMethods in oshi.hardware.common.platform.unix.freebsd that return types with arguments of type SoundCard -
Uses of SoundCard in oshi.hardware.common.platform.unix.netbsd
Methods in oshi.hardware.common.platform.unix.netbsd that return types with arguments of type SoundCard -
Uses of SoundCard in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement SoundCardMethods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type SoundCard