Uses of Interface
oshi.hardware.VirtualMemory

Packages that use VirtualMemory
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems