Class AbstractDisplay
java.lang.Object
oshi.hardware.common.AbstractDisplay
- All Implemented Interfaces:
Display
- Direct Known Subclasses:
UnixDisplay
A Display
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedAbstractDisplay(byte[] edid) Constructor for AbstractDisplay from a raw EDID byte array.protectedAbstractDisplay(DisplayInfo displayInfo) Constructor for AbstractDisplay from decoded display information, used when a display reports its attributes without providing an EDID. -
Method Summary
-
Constructor Details
-
AbstractDisplay
protected AbstractDisplay(byte[] edid) Constructor for AbstractDisplay from a raw EDID byte array.- Parameters:
edid- a byte array representing a display EDID
-
AbstractDisplay
Constructor for AbstractDisplay from decoded display information, used when a display reports its attributes without providing an EDID. Pass a syntheticDisplayInfoto expose a synthesized EDID.- Parameters:
displayInfo- the decoded display information
-
-
Method Details
-
getEdid
Deprecated.Description copied from interface:DisplayThe EDID byte array.- Specified by:
getEdidin interfaceDisplay- Returns:
- The EDID byte array, either reported by the display or, when
DisplayInfo.isEdidSynthetic()istrue, synthesized from the display's reported attributes.
-
getDisplayInfo
Description copied from interface:DisplayThe decoded display information.- Specified by:
getDisplayInfoin interfaceDisplay- Returns:
- A
DisplayInfoholding the display's decoded attributes.
-
toString
-