Uses of Class
oshi.hardware.common.AbstractCentralProcessor
Packages that use AbstractCentralProcessor
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.linux
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.linux -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.linux.nativefree
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux central processor implementation. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.mac
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassBase class for macOS CentralProcessor implementations. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unixModifier and TypeClassDescriptionclassShared CentralProcessor logic for thedmesg-parsing BSDs (OpenBSD and NetBSD). -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.aixModifier and TypeClassDescriptionclassAbstract base for AIX CentralProcessor. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.freebsdModifier and TypeClassDescriptionclassShared FreeBSD CentralProcessor logic. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.netbsd
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.netbsdModifier and TypeClassDescriptionclassNetBSD Central Processor implementation. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.openbsdModifier and TypeClassDescriptionclassShared OpenBSD CentralProcessor logic. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.unix.solarisModifier and TypeClassDescriptionclassAbstract base for the Solaris CPU. -
Uses of AbstractCentralProcessor in oshi.hardware.common.platform.windows
Subclasses of AbstractCentralProcessor in oshi.hardware.common.platform.windowsModifier and TypeClassDescriptionclassCommon non-native logic for Windows Central Processor implementations.