Uses of Class
oshi.hardware.common.AbstractComputerSystem
Packages that use AbstractComputerSystem
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractComputerSystem in oshi.hardware.common.platform.mac
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.mac -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.aixModifier and TypeClassDescriptionfinal classHardware data obtained from lsattr -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.netbsd
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.netbsd -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.windows
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.windows