Uses of Class
oshi.hardware.common.AbstractGraphicsCard
Packages that use AbstractGraphicsCard
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.linux
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.linuxModifier and TypeClassDescriptionclassGraphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files. -
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.mac
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassGraphics card info obtained by system_profiler SPDisplaysDataType. -
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.freebsdModifier and TypeClassDescriptionclassGraphics Card info obtained from pciconf -
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.openbsdModifier and TypeClassDescriptionclassGraphics Card info obtained from pcidump -
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.unix.solarisModifier and TypeClassDescriptionclassGraphics Card info obtained from prtconf