Uses of Class
oshi.hardware.common.AbstractNetworkIF

Packages that use AbstractNetworkIF
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems