Uses of Class
oshi.hardware.common.AbstractSoundCard

Packages that use AbstractSoundCard
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM modules.