Enum Class LinuxHWDiskStore.UdevStat

java.lang.Object
java.lang.Enum<LinuxHWDiskStore.UdevStat>
oshi.hardware.common.platform.linux.LinuxHWDiskStore.UdevStat
All Implemented Interfaces:
Serializable, Comparable<LinuxHWDiskStore.UdevStat>, Constable
Enclosing class:
LinuxHWDiskStore

protected static enum LinuxHWDiskStore.UdevStat extends Enum<LinuxHWDiskStore.UdevStat>
Field ordering in udev stat output.
  • Enum Constant Details

  • Method Details

    • values

      public static LinuxHWDiskStore.UdevStat[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LinuxHWDiskStore.UdevStat valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getOrder

      public int getOrder()
      Gets the field order index.
      Returns:
      the order