Class LinuxLogicalVolumeGroup

java.lang.Object
oshi.hardware.common.AbstractLogicalVolumeGroup
oshi.hardware.common.platform.linux.LinuxLogicalVolumeGroup
All Implemented Interfaces:
LogicalVolumeGroup

public class LinuxLogicalVolumeGroup extends AbstractLogicalVolumeGroup
Linux implementation of LogicalVolumeGroup.
  • Field Details

  • Constructor Details

    • LinuxLogicalVolumeGroup

      protected LinuxLogicalVolumeGroup(String name, Map<String, Set<String>> lvMap, Set<String> pvSet)
      Creates a LinuxLogicalVolumeGroup.
      Parameters:
      name - the volume group name
      lvMap - the logical volume map
      pvSet - the physical volume set
  • Method Details

    • queryPhysicalVolumes

      protected static Map<String, Set<String>> queryPhysicalVolumes()
      Populates the physical volumes map from the pvs command output. Requires elevated permissions; may return an empty map if the command fails.
      Returns:
      map of VG name to set of PV device paths