Uses of Class
oshi.hardware.common.platform.linux.LinuxHWDiskStore
Packages that use LinuxHWDiskStore
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
-
Uses of LinuxHWDiskStore in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux with parameters of type LinuxHWDiskStoreModifier and TypeMethodDescriptionprotected static voidLinuxHWDiskStore.addDeviceMapperPartition(LinuxHWDiskStore store, Map<String, String> mountsMap, String dmUuid, String vgName, String lvName, String dmName, String devnode, String sysname, String sysPath, String fsType, String fsUuid, String fsLabel, long size, int major, int minor) Adds a partition entry for a supported device-mapper device.protected static voidLinuxHWDiskStore.computeDiskStats(LinuxHWDiskStore store, String devstat) Computes and sets disk statistics from a stat string. -
Uses of LinuxHWDiskStore in oshi.hardware.common.platform.linux.nativefree
Subclasses of LinuxHWDiskStore in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux disk store implementation.