Uses of Enum Class
oshi.hardware.common.platform.linux.LinuxHWDiskStore.UdevStat
Packages that use LinuxHWDiskStore.UdevStat
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
-
Uses of LinuxHWDiskStore.UdevStat in oshi.hardware.common.platform.linux
Subclasses with type arguments of type LinuxHWDiskStore.UdevStat in oshi.hardware.common.platform.linuxModifier and TypeClassDescriptionprotected static enumField ordering in udev stat output.Methods in oshi.hardware.common.platform.linux that return LinuxHWDiskStore.UdevStatModifier and TypeMethodDescriptionstatic LinuxHWDiskStore.UdevStatReturns the enum constant of this class with the specified name.static LinuxHWDiskStore.UdevStat[]LinuxHWDiskStore.UdevStat.values()Returns an array containing the constants of this enum class, in the order they are declared.