Uses of Enum Class
oshi.hardware.common.platform.linux.LinuxPowerSource.Prop
Packages that use LinuxPowerSource.Prop
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
-
Uses of LinuxPowerSource.Prop in oshi.hardware.common.platform.linux
Subclasses with type arguments of type LinuxPowerSource.Prop in oshi.hardware.common.platform.linuxModifier and TypeClassDescriptionprotected static enumPower supply uevent properties from sysfs.Methods in oshi.hardware.common.platform.linux that return LinuxPowerSource.PropModifier and TypeMethodDescriptionstatic LinuxPowerSource.PropReturns the enum constant of this class with the specified name.static LinuxPowerSource.Prop[]LinuxPowerSource.Prop.values()Returns an array containing the constants of this enum class, in the order they are declared.Method parameters in oshi.hardware.common.platform.linux with type arguments of type LinuxPowerSource.PropModifier and TypeMethodDescriptionprotected static LinuxPowerSourceLinuxPowerSource.buildPowerSource(String name, Map<LinuxPowerSource.Prop, String> props) Builds a LinuxPowerSource from parsed uevent properties.