Class LinuxCentralProcessorNF
java.lang.Object
oshi.hardware.common.AbstractCentralProcessor
oshi.hardware.common.platform.linux.LinuxCentralProcessor
oshi.hardware.common.platform.linux.nativefree.LinuxCentralProcessorNF
- All Implemented Interfaces:
CentralProcessor
Native-free Linux central processor implementation. Extends
LinuxCentralProcessor, overriding udev-dependent
methods with sysfs-based alternatives.-
Nested Class Summary
Nested classes/interfaces inherited from interface CentralProcessor
CentralProcessor.LogicalProcessor, CentralProcessor.PhysicalProcessor, CentralProcessor.ProcessorCache, CentralProcessor.ProcessorIdentifier, CentralProcessor.TickTypeModifier and TypeInterfaceDescriptionstatic classA class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.static classA class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.static classA class representing CPU Cache Memory.static final classA class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)static enumIndex of CPU tick counters in theCentralProcessor.getSystemCpuLoadTicks()andCentralProcessor.getProcessorCpuLoadTicks()arrays. -
Constructor Summary
ConstructorsConstructorDescriptionCreates a new native-free Linux central processor. -
Method Summary
Modifier and TypeMethodDescriptionprotected booleanqueryCurrentFreqFromUdev(long[] freqs) Fills the freqs array from udev cpu-freq source.protected longQueries the maximum frequency from udev.protected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> Reads processor topology using udev.Methods inherited from class LinuxCentralProcessor
getLogicalProcessorFromSyspath, getSystemLoadAverage, initProcessorCounts, queryContextSwitches, queryCurrentFreq, queryCurrentFreqFromSysfs, queryHwcap, queryInterrupts, queryMaxFreq, queryMaxFreqFromCpuFreqPath, queryMaxFreqFromSysfs, queryProcessorCpuLoadTicks, queryProcessorId, querySystemCpuLoadTicks, readTopologyFromSysfsModifier and TypeMethodDescriptionprotected static CentralProcessor.LogicalProcessorgetLogicalProcessorFromSyspath(String syspath, Set<CentralProcessor.ProcessorCache> caches, String modAlias, Map<Integer, Integer> coreEfficiencyMap, Map<Integer, String> modAliasMap) getLogicalProcessorFromSyspath.double[]getSystemLoadAverage(int nelem) Returns the system load average for the number of elements specified, up to 3, representing 1, 5, and 15 minutes.protected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> Initializes logical and physical processor lists and feature flags.longGet number of context switcheslong[]Get processor current frequency.protected static booleanqueryCurrentFreqFromSysfs(long[] freqs) queryCurrentFreqFromSysfs.protected longQueries the hardware capabilities from the auxiliary vector.longGet number of interruptslongGet processor max frequency.protected static longqueryMaxFreqFromCpuFreqPath(String cpuFreqPath) Queries the maximum frequency from a cpufreq path.protected static longQueries the maximum frequency from sysfs.long[][]Get the processor CPU load ticksprotected CentralProcessor.ProcessorIdentifierUpdates logical and physical processor counts and arrayslong[]Get the system CPU load ticksprotected static Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> Reads processor topology from sysfs using the default CPU path.Methods inherited from class AbstractCentralProcessor
createProcessorID, createProcessorID, createProcListFromDmesg, getContextSwitches, getCurrentFreq, getFeatureFlags, getInterrupts, getLogicalProcessorCount, getLogicalProcessors, getMaxFreq, getPhysicalPackageCount, getPhysicalProcessorCount, getPhysicalProcessors, getProcessorCaches, getProcessorCpuLoadBetweenTicks, getProcessorCpuLoadBetweenTicks, getProcessorCpuLoadTicks, getProcessorIdentifier, getSystemCpuLoadBetweenTicks, getSystemCpuLoadBetweenTicks, getSystemCpuLoadTicks, orderedProcCaches, toStringModifier and TypeMethodDescriptionprotected static StringcreateProcessorID(String stepping, String model, String family, String[] flags) Creates a Processor ID by encoding the stepping, model, family, and feature flags.protected static StringcreateProcessorID(String stepping, String model, String family, String[] flags, long hwcap) Creates a Processor ID by encoding the stepping, model, family, and feature flags.protected List<CentralProcessor.PhysicalProcessor> createProcListFromDmesg(List<CentralProcessor.LogicalProcessor> logProcs, Map<Integer, String> dmesg) Creates a list of physical processors from dmesg output.longGet the number of system-wide context switches which have occurred.long[]Attempts to return the current frequency (in Hz), of the logical processors on this CPU.Returns a list of platform-specific strings which identify CPU Feature Flags.longGet the number of system-wide interrupts which have occurred.intGet the number of logical CPUs available for processing.Returns anUnmodifiableListof the CPU's logical processors.longMaximum frequeny (in Hz), of the logical processors on this CPU.intGet the number of packages/sockets in the system.intGet the number of physical CPUs/cores available for processing.Returns anUnmodifiableListof the CPU's physical processors.Makes a best-effort attempt to identify the CPU's processor caches.double[]getProcessorCpuLoadBetweenTicks(long[][] oldTicks) Returns the "recent cpu usage" for all logical processors by counting ticks fromCentralProcessor.getProcessorCpuLoadTicks()between the user-provided value from a previous call.double[]getProcessorCpuLoadBetweenTicks(long[][] oldTicks, long[][] ticks) Returns the "recent cpu usage" for all logical processors by counting ticks fromCentralProcessor.getProcessorCpuLoadTicks()between the user-provided value from a previous call.long[][]Get Processor CPU Load tick counters.The CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU).doublegetSystemCpuLoadBetweenTicks(long[] oldTicks) Returns the "recent cpu usage" for the whole system by counting ticks fromCentralProcessor.getSystemCpuLoadTicks()between the user-provided value from a previous call.doublegetSystemCpuLoadBetweenTicks(long[] oldTicks, long[] ticks) Returns the "recent cpu usage" for the whole system by counting ticks between two user-provided values, retrieved fromCentralProcessor.getSystemCpuLoadTicks()at different points in time.long[]Get System-wide CPU Load tick counters.static List<CentralProcessor.ProcessorCache> Filters a set of processor caches to an ordered listtoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface CentralProcessor
getProcessorCpuLoad, getSystemCpuLoadModifier and TypeMethodDescriptiondefault double[]getProcessorCpuLoad(long delay) This is a convenience method which collects an initial set of ticks usingCentralProcessor.getProcessorCpuLoadTicks()and passes that result toCentralProcessor.getProcessorCpuLoadBetweenTicks(long[][])after the specified delay.default doublegetSystemCpuLoad(long delay) This is a convenience method which collects an initial set of ticks usingCentralProcessor.getSystemCpuLoadTicks()and passes that result toCentralProcessor.getSystemCpuLoadBetweenTicks(long[])after the specified delay.
-
Constructor Details
-
LinuxCentralProcessorNF
public LinuxCentralProcessorNF()Creates a new native-free Linux central processor.
-
-
Method Details
-
readTopologyWithUdev
protected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer,Integer>, Map<Integer, readTopologyWithUdev()String>> Description copied from class:LinuxCentralProcessorReads processor topology using udev.- Specified by:
readTopologyWithUdevin classLinuxCentralProcessor- Returns:
- a quartet of logical processors, caches, efficiency map, and modalias map
-
queryCurrentFreqFromUdev
protected boolean queryCurrentFreqFromUdev(long[] freqs) Description copied from class:LinuxCentralProcessorFills the freqs array from udev cpu-freq source. Returns true if successful (max > 0). Subclasses provide the implementation.- Specified by:
queryCurrentFreqFromUdevin classLinuxCentralProcessor- Parameters:
freqs- array to fill with per-logical-processor frequencies in Hz- Returns:
- true if frequencies were successfully read
-
queryMaxFreqFromUdev
protected long queryMaxFreqFromUdev()Description copied from class:LinuxCentralProcessorQueries the maximum frequency from udev.- Specified by:
queryMaxFreqFromUdevin classLinuxCentralProcessor- Returns:
- the maximum frequency in Hz
-