Class LinuxHWDiskStoreNF

All Implemented Interfaces:
HWDiskStore

@ThreadSafe public final class LinuxHWDiskStoreNF extends LinuxHWDiskStore
Native-free Linux disk store implementation. Enumerates block devices from /sys/block/ and reads stats from sysfs, without requiring udev.
  • Method Details

    • getDisks

      public static List<HWDiskStore> getDisks()
      Gets disk stores on this machine.
      Returns:
      a list of HWDiskStore objects
    • updateAttributes

      public boolean updateAttributes()
      Description copied from interface: HWDiskStore
      Make a best effort to update all the statistics about the drive without needing to recreate the drive list. This method provides for more frequent periodic updates of individual drive statistics but may be less efficient to use if updating all drives. It will not detect if a removable drive has been removed and replaced by a different drive in between method calls.
      Returns:
      True if the update was (probably) successful, false if the disk was not found