Class LinuxNetworkIfNF
java.lang.Object
oshi.hardware.common.AbstractNetworkIF
oshi.hardware.common.platform.linux.LinuxNetworkIF
oshi.hardware.common.platform.linux.nativefree.LinuxNetworkIfNF
- All Implemented Interfaces:
NetworkIF
Native-free Linux network interface implementation. Uses sysfs for model identification.
-
Nested Class Summary
Nested classes/interfaces inherited from interface NetworkIF
NetworkIF.IfOperStatusModifier and TypeInterfaceDescriptionstatic enumThe current operational state of a network interface. -
Field Summary
Fields inherited from class AbstractNetworkIF
bytesRecv, bytesSent, collisions, inDrops, inErrors, outErrors, packetsRecv, packetsSent, speed, timeStampModifier and TypeFieldDescriptionprotected longprotected longprotected longprotected longprotected longprotected longprotected longprotected longprotected longprotected long -
Method Summary
Modifier and TypeMethodDescriptiongetNetworks(boolean includeLocalInterfaces) Gets network interfaces on this machine.Methods inherited from class LinuxNetworkIF
getIfAlias, getIfOperStatus, getIfType, isConnectorPresent, parseIfOperStatus, queryIfModelFromSysfs, updateAttributesModifier and TypeMethodDescriptionTheifAliasas described in RFC 2863.TheifOperStatusas described in RFC 2863.int(Windows, macOS) The NDIS Interface Type.boolean(Windows Vista and higher) Set if a connector is present on the network interface.protected static NetworkIF.IfOperStatusparseIfOperStatus(String operState) Parses the operational status from a sysfs operstate string.protected static StringqueryIfModelFromSysfs(String name) Reads vendor/model from the sysfs uevent file.booleanUpdates interface network statistics on this interface.Methods inherited from class AbstractNetworkIF
getBytesRecv, getBytesSent, getCollisions, getDisplayName, getIndex, getInDrops, getInErrors, getIPv4addr, getIPv6addr, getMacaddr, getMTU, getName, getNetworkInterfaces, getOutErrors, getPacketsRecv, getPacketsSent, getPrefixLengths, getSpeed, getSubnetMasks, getTimeStamp, isKnownVmMacAddr, queryNetworkInterface, toStringModifier and TypeMethodDescriptionlongGetter for the fieldbytesRecv.longGetter for the fieldbytesSent.longGetter for the fieldcollisions.Interface description.intgetIndex()Interface index.longGetter for the fieldinDrops.longGetter for the fieldinErrors.String[]The Internet Protocol (IP) v4 address.String[]The Internet Protocol (IP) v6 address.The Media Access Control (MAC) address.longgetMTU()The interface Maximum Transmission Unit (MTU).getName()Interface name.protected static List<NetworkInterface> getNetworkInterfaces(boolean includeLocalInterfaces) Returns network interfaces on this machine.longGetter for the fieldoutErrors.longGetter for the fieldpacketsRecv.longGetter for the fieldpacketsSent.Short[]The Internet Protocol (IP) v6 address.longgetSpeed()Getter for the fieldspeed.Short[]The Internet Protocol (IP) v4 subnet masks.longGetter for the fieldtimeStamp.booleanDetermines if the MAC address on this interface corresponds to a known Virtual Machine.Gets theNetworkInterfaceobject.toString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface NetworkIF
getNdisPhysicalMediumTypeModifier and TypeMethodDescriptiondefault int(Windows Vista and higher only) The NDIS physical medium type.
-
Method Details
-
getNetworks
-