Package oshi.hardware.common.platform.linux
package oshi.hardware.common.platform.linux
Provides common Linux hardware implementations shared by JNA and FFM modules.
-
ClassDescriptionLinux Bluetooth device enumeration via BlueZ filesystem paths.A CPU as defined in Linux /proc.Memory obtained by /proc/meminfo and sysinfo.totalramLinux
GpuStatssession.Graphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.Parsed graphics card attributes used to construct concrete subclass instances.LinuxHardwareAbstractionLayer class.Linux hard disk implementation.Field ordering in udev stat output.Linux implementation of LogicalVolumeGroup.LinuxNetworks class.A Power SourcePower supply uevent properties from sysfs.Linux USB device base class.