Uses of Package
oshi.hardware.common.platform.linux
Packages that use oshi.hardware.common.platform.linux
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
-
Classes in oshi.hardware.common.platform.linux used by oshi.hardware.common.platform.linuxClassDescriptionParsed graphics card attributes used to construct concrete subclass instances.Linux hard disk implementation.Field ordering in udev stat output.A Power SourcePower supply uevent properties from sysfs.Linux USB device base class.
-
Classes in oshi.hardware.common.platform.linux used by oshi.hardware.common.platform.linux.nativefreeClassDescriptionA CPU as defined in Linux /proc.LinuxHardwareAbstractionLayer class.Linux hard disk implementation.LinuxNetworks class.Linux USB device base class.