Interface IOKitProvider.RegistryEntry

Enclosing interface:
IOKitProvider

public static interface IOKitProvider.RegistryEntry
A handle to an IORegistry entry, providing property access.
  • Method Details

    • getName

      String getName()
      Gets the name of this registry entry.
      Returns:
      the entry name, or null if unavailable
    • getByteArrayProperty

      byte[] getByteArrayProperty(String key)
      Gets a byte array property from this registry entry.
      Parameters:
      key - the property key
      Returns:
      the property value as a byte array, or null if not found
    • getStringProperty

      String getStringProperty(String key)
      Gets a string property from this registry entry.
      Parameters:
      key - the property key
      Returns:
      the property value as a string, or null if not found
    • getIntegerProperty

      Integer getIntegerProperty(String key)
      Gets an integer property from this registry entry.
      Parameters:
      key - the property key
      Returns:
      the property value as an Integer, or null if not found
    • getBooleanProperty

      Boolean getBooleanProperty(String key)
      Gets a boolean property from this registry entry.
      Parameters:
      key - the property key
      Returns:
      the property value as a Boolean, or null if not found