Interface MacGraphicsCard.GraphicsCardFactory

Enclosing class:
MacGraphicsCard
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface protected static interface MacGraphicsCard.GraphicsCardFactory
Factory for creating GraphicsCard instances.
  • Method Summary

    Modifier and Type
    Method
    Description
    create(String name, String deviceId, String vendor, String versionInfo, long vram)
    Creates a GraphicsCard instance.
  • Method Details

    • create

      GraphicsCard create(String name, String deviceId, String vendor, String versionInfo, long vram)
      Creates a GraphicsCard instance.
      Parameters:
      name - the card name
      deviceId - the device ID
      vendor - the vendor
      versionInfo - the version info
      vram - the VRAM in bytes
      Returns:
      the graphics card