Interface MacGraphicsCard.SysctlLong
- Enclosing class:
MacGraphicsCard
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Functional interface for sysctl long queries.
-
Method Summary
-
Method Details
-
get
Gets a sysctl long value.- Parameters:
name- the sysctl namedefaultValue- the default value- Returns:
- the sysctl value
-