Interface SysctlProvider


public interface SysctlProvider
Abstracts sysctl operations so that Mac base classes can query sysctl values without depending on JNA or FFM directly.
  • Method Details

    • sysctlInt

      int sysctlInt(String name, int defaultValue)
      Gets a sysctl int value.
      Parameters:
      name - the sysctl name
      defaultValue - the default value if not found
      Returns:
      the sysctl value
    • sysctlIntNoWarn

      int sysctlIntNoWarn(String name, int defaultValue)
      Gets a sysctl int value without logging warnings on failure.
      Parameters:
      name - the sysctl name
      defaultValue - the default value if not found
      Returns:
      the sysctl value
    • sysctlLong

      long sysctlLong(String name, long defaultValue)
      Gets a sysctl long value.
      Parameters:
      name - the sysctl name
      defaultValue - the default value if not found
      Returns:
      the sysctl value
    • sysctlString

      String sysctlString(String name, String defaultValue)
      Gets a sysctl string value.
      Parameters:
      name - the sysctl name
      defaultValue - the default value if not found
      Returns:
      the sysctl value
    • sysctlStringNoWarn

      String sysctlStringNoWarn(String name, String defaultValue)
      Gets a sysctl string value without logging warnings on failure.
      Parameters:
      name - the sysctl name
      defaultValue - the default value if not found
      Returns:
      the sysctl value