Class WindowsComputerSystem
- All Implemented Interfaces:
ComputerSystem
WmiQueryExecutor.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGet the computer system hardware UUID, if available.Get the computer system manufacturer.getModel()Get the computer system model.Get the computer system serial number, if available.protected abstract WmiQueryExecutorReturns the WMI query executor for this platform.Methods inherited from class AbstractComputerSystem
createBaseboard, createFirmware, getBaseboard, getFirmware, toString
-
Constructor Details
-
WindowsComputerSystem
public WindowsComputerSystem()
-
-
Method Details
-
getWmiQueryExecutor
Returns the WMI query executor for this platform.- Returns:
- a non-null
WmiQueryExecutor
-
getManufacturer
Description copied from interface:ComputerSystemGet the computer system manufacturer.- Returns:
- The manufacturer.
-
getModel
Description copied from interface:ComputerSystemGet the computer system model.- Returns:
- The model.
-
getSerialNumber
Description copied from interface:ComputerSystemGet the computer system serial number, if available.Performs a best-effort attempt to retrieve a unique serial number from the computer system. This may originate from the baseboard, BIOS, processor, etc.
This value is provided for information only. Caution should be exercised if using this result to "fingerprint" a system for licensing or other purposes, as the result may change based on program permissions or installation of software packages. Specifically, on Linux and FreeBSD, this requires either root permissions, or installation of the (deprecated) HAL library (lshal command). Linux also attempts to read the dmi/id serial number files in sysfs, which are read-only root by default but may have permissions altered by the user.
- Returns:
- the System Serial Number, if available, otherwise returns "unknown"
-
getHardwareUUID
Description copied from interface:ComputerSystemGet the computer system hardware UUID, if available.Performs a best-effort attempt to retrieve the hardware UUID.
- Returns:
- the Hardware UUID, if available, otherwise returns "unknown"
-