Class WindowsPowerSource
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.common.platform.windows.WindowsPowerSource
- All Implemented Interfaces:
PowerSource
A Power Source
-
Nested Class Summary
Nested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnits -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final int -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedWindowsPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Method Summary
Methods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, queryPowerSources, toString, updateAttributes
-
Field Details
-
IOCTL_BATTERY_QUERY_TAG
protected static final int IOCTL_BATTERY_QUERY_TAG- See Also:
-
IOCTL_BATTERY_QUERY_INFORMATION
protected static final int IOCTL_BATTERY_QUERY_INFORMATION- See Also:
-
IOCTL_BATTERY_QUERY_STATUS
protected static final int IOCTL_BATTERY_QUERY_STATUS- See Also:
-
BATTERY_SYSTEM_BATTERY
protected static final int BATTERY_SYSTEM_BATTERY- See Also:
-
BATTERY_IS_SHORT_TERM
protected static final int BATTERY_IS_SHORT_TERM- See Also:
-
BATTERY_CAPACITY_RELATIVE
protected static final int BATTERY_CAPACITY_RELATIVE- See Also:
-
BATTERY_POWER_ON_LINE
protected static final int BATTERY_POWER_ON_LINE- See Also:
-
BATTERY_DISCHARGING
protected static final int BATTERY_DISCHARGING- See Also:
-
BATTERY_CHARGING
protected static final int BATTERY_CHARGING- See Also:
-
BATTERY_INFORMATION_LEVEL
protected static final int BATTERY_INFORMATION_LEVEL- See Also:
-
BATTERY_TEMPERATURE_LEVEL
protected static final int BATTERY_TEMPERATURE_LEVEL- See Also:
-
BATTERY_ESTIMATED_TIME_LEVEL
protected static final int BATTERY_ESTIMATED_TIME_LEVEL- See Also:
-
BATTERY_DEVICE_NAME_LEVEL
protected static final int BATTERY_DEVICE_NAME_LEVEL- See Also:
-
BATTERY_MANUFACTURE_DATE_LEVEL
protected static final int BATTERY_MANUFACTURE_DATE_LEVEL- See Also:
-
BATTERY_MANUFACTURE_NAME_LEVEL
protected static final int BATTERY_MANUFACTURE_NAME_LEVEL- See Also:
-
BATTERY_SERIAL_NUMBER_LEVEL
protected static final int BATTERY_SERIAL_NUMBER_LEVEL- See Also:
-
-
Constructor Details
-
WindowsPowerSource
protected WindowsPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature)
-