Uses of Package
oshi.hardware

Packages that use oshi.hardware
Package
Description
Provides functions to query information on AIX
Provides parsing utilities for commands shared by BSD-derived platforms (e.g.
Provides parsing utilities for BSD disk-related commands (e.g.
Provides functions to query FreeBSD disk information
Provides functions to query Solaris disk information.
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Native-free OSHI entry point for Linux.
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access
Provides driver utilities common to unix systems that do not require native access
  • Class
    Description
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
  • Class
    Description
    Units of Battery Capacity
  • Class
    Description
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
  • Class
    Description
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
  • Class
    Description
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
  • Classes in oshi.hardware used by oshi.hardware
    Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    The type of cache.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    Display refers to the information regarding a video source and monitor identified by the EDID standard.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    A session handle for sampling dynamic GPU metrics.
    An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
    Represents a graphics card (GPU) installed in the system.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
    A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
    A network interface in the machine, including statistics.
    The current operational state of a network interface.
    The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
    Printer status enumeration.
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    Display refers to the information regarding a video source and monitor identified by the EDID standard.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    A session handle for sampling dynamic GPU metrics.
    An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
    Represents a graphics card (GPU) installed in the system.
    A hardware abstraction layer.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
    A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
    A network interface in the machine, including statistics.
    The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
    Printer status enumeration.
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    Display refers to the information regarding a video source and monitor identified by the EDID standard.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    A session handle for sampling dynamic GPU metrics.
    An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
    Represents a graphics card (GPU) installed in the system.
    A hardware abstraction layer.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
    A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
    A network interface in the machine, including statistics.
    The current operational state of a network interface.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing CPU Cache Memory.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A hardware abstraction layer.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A network interface in the machine, including statistics.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    A USB device is a device connected via a USB port, possibly internally/permanently.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A hardware abstraction layer.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
    A network interface in the machine, including statistics.
    The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    Display refers to the information regarding a video source and monitor identified by the EDID standard.
    Represents a graphics card (GPU) installed in the system.
    A network interface in the machine, including statistics.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
    Printer status enumeration.
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A network interface in the machine, including statistics.
    The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    Display refers to the information regarding a video source and monitor identified by the EDID standard.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A hardware abstraction layer.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A network interface in the machine, including statistics.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
  • Class
    Description
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
    A class representing CPU Cache Memory.
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Represents a graphics card (GPU) installed in the system.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A network interface in the machine, including statistics.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
    Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
    A USB device is a device connected via a USB port, possibly internally/permanently.
    The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Class
    Description
    The Baseboard represents the system board, also called motherboard, logic board, etc.
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The Firmware represents the low level BIOS or equivalent.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    A session handle for sampling dynamic GPU metrics.
    An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
    A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
    A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
    A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
    Units of Battery Capacity
    Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
    Printer status enumeration.
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
  • Classes in oshi.hardware used by oshi.nativefree
    Class
    Description
    A hardware abstraction layer.
  • Classes in oshi.hardware used by oshi.spi
    Class
    Description
    A hardware abstraction layer.
  • Classes in oshi.hardware used by oshi.util
    Class
    Description
    This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
    The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
    The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
    Sensors include hardware sensors to monitor temperature, fan speed, and other information.
  • Class
    Description
    Printer status enumeration.