Class AbstractFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
- All Implemented Interfaces:
FileSystem
- Direct Known Subclasses:
FreeBsdFileSystem, LinuxFileSystem, MacFileSystem, OpenBsdFileSystem
Common methods for filesystem implementations
-
Field Summary
FieldsModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface FileSystem
getFileStores, getMaxFileDescriptors, getMaxFileDescriptorsPerProcess, getOpenFileDescriptorsModifier and TypeMethodDescriptiongetFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.longThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.
-
Field Details
-
NETWORK_FS_TYPES
-
PSEUDO_FS_TYPES
-
-
Constructor Details
-
AbstractFileSystem
protected AbstractFileSystem()Default constructor.
-
-
Method Details
-
getFileStores
Description copied from interface:FileSystemGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.- Specified by:
getFileStoresin interfaceFileSystem- Returns:
- A list of
OSFileStoreobjects or an empty array if none are present.
-