Uses of Class
oshi.software.common.AbstractFileSystem
Packages that use AbstractFileSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
-
Uses of AbstractFileSystem in oshi.software.common.os.linux
Subclasses of AbstractFileSystem in oshi.software.common.os.linuxModifier and TypeClassDescriptionclassThe Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.common.os.linux.nativefree
Subclasses of AbstractFileSystem in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux file system implementation. -
Uses of AbstractFileSystem in oshi.software.common.os.mac
Subclasses of AbstractFileSystem in oshi.software.common.os.macModifier and TypeClassDescriptionclassCommon constants and configuration for macOS file system implementations. -
Uses of AbstractFileSystem in oshi.software.common.os.unix.freebsd
Subclasses of AbstractFileSystem in oshi.software.common.os.unix.freebsd -
Uses of AbstractFileSystem in oshi.software.common.os.unix.openbsd
Subclasses of AbstractFileSystem in oshi.software.common.os.unix.openbsd