Uses of Class
oshi.software.common.AbstractOSProcess
Packages that use AbstractOSProcess
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides shared abstract base classes for the
/proc-filesystem Unix operating systemsProvides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Uses of AbstractOSProcess in oshi.software.common.os.linux
Subclasses of AbstractOSProcess in oshi.software.common.os.linux -
Uses of AbstractOSProcess in oshi.software.common.os.linux.nativefree
Subclasses of AbstractOSProcess in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux OS process implementation. -
Uses of AbstractOSProcess in oshi.software.common.os.mac
Subclasses of AbstractOSProcess in oshi.software.common.os.macModifier and TypeClassDescriptionclassAbstract base shared by the macOS OSProcess implementations (JNA and FFM). -
Uses of AbstractOSProcess in oshi.software.common.os.unix
Subclasses of AbstractOSProcess in oshi.software.common.os.unixModifier and TypeClassDescriptionclassAbstract base for the/proc-filesystem Unix OSProcess implementations (Solaris and AIX). -
Uses of AbstractOSProcess in oshi.software.common.os.unix.aix
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.aix -
Uses of AbstractOSProcess in oshi.software.common.os.unix.bsd
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.bsdModifier and TypeClassDescriptionclassAbstract base shared by the BSD-family OSProcess implementations (FreeBSD, OpenBSD, DragonFly, NetBSD). -
Uses of AbstractOSProcess in oshi.software.common.os.unix.dragonflybsd
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.dragonflybsd -
Uses of AbstractOSProcess in oshi.software.common.os.unix.freebsd
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.freebsd -
Uses of AbstractOSProcess in oshi.software.common.os.unix.netbsd
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.netbsd -
Uses of AbstractOSProcess in oshi.software.common.os.unix.openbsd
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.openbsd -
Uses of AbstractOSProcess in oshi.software.common.os.unix.solaris
Subclasses of AbstractOSProcess in oshi.software.common.os.unix.solaris -
Uses of AbstractOSProcess in oshi.software.common.os.windows
Subclasses of AbstractOSProcess in oshi.software.common.os.windowsModifier and TypeClassDescriptionclassCommon base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.