Uses of Class
oshi.software.common.AbstractOperatingSystem
Packages that use AbstractOperatingSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Uses of AbstractOperatingSystem in oshi.software.common.os.linux
Subclasses of AbstractOperatingSystem in oshi.software.common.os.linuxModifier and TypeClassDescriptionclassLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds. -
Uses of AbstractOperatingSystem in oshi.software.common.os.linux.nativefree
Subclasses of AbstractOperatingSystem in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux operating system implementation. -
Uses of AbstractOperatingSystem in oshi.software.common.os.mac
Subclasses of AbstractOperatingSystem in oshi.software.common.os.macModifier and TypeClassDescriptionclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001. -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.bsd
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.bsdModifier and TypeClassDescriptionclassAbstract base shared by the BSD-family OperatingSystem implementations (FreeBSD, OpenBSD, DragonFly, NetBSD). -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.dragonflybsd
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.dragonflybsdModifier and TypeClassDescriptionclassAbstract base shared by the DragonFly BSD OperatingSystem implementations (JNA and FFM). -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.freebsd
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.freebsdModifier and TypeClassDescriptionclassAbstract base shared by the FreeBSD OperatingSystem implementations (JNA and FFM). -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.netbsd
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.netbsdModifier and TypeClassDescriptionclassNetBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix. -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.openbsd
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.openbsdModifier and TypeClassDescriptionclassAbstract base shared by the OpenBSD OperatingSystem implementations (JNA and FFM). -
Uses of AbstractOperatingSystem in oshi.software.common.os.unix.solaris
Subclasses of AbstractOperatingSystem in oshi.software.common.os.unix.solarisModifier and TypeClassDescriptionclassSolaris is a non-free Unix operating system originally developed by Sun Microsystems. -
Uses of AbstractOperatingSystem in oshi.software.common.os.windows
Subclasses of AbstractOperatingSystem in oshi.software.common.os.windowsModifier and TypeClassDescriptionclassCommon base class for Windows operating system implementations.