Class LinuxOSFileStore
java.lang.Object
oshi.software.common.AbstractOSFileStore
oshi.software.common.os.linux.LinuxOSFileStore
- All Implemented Interfaces:
OSFileStore
OSFileStore implementation
-
Constructor Summary
ConstructorsConstructorDescriptionLinuxOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes, LinuxFileSystem fs) Creates a LinuxOSFileStore. -
Method Summary
Modifier and TypeMethodDescriptionbooleanMake a best effort to update all the statistics about the file store without needing to recreate the file store list.Methods inherited from class AbstractOSFileStore
getDescription, getFreeInodes, getFreeSpace, getLabel, getLogicalVolume, getMount, getName, getOptions, getTotalInodes, getTotalSpace, getType, getUsableSpace, getUUID, getVolume, isLocal, toString, updateFrom, updateSpace, updateSpaceAndInodes
-
Constructor Details
-
LinuxOSFileStore
public LinuxOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes, LinuxFileSystem fs) Creates a LinuxOSFileStore.- Parameters:
name- the namevolume- the volumelabel- the labelmount- the mount pointoptions- the mount optionsuuid- the UUIDlocal- whether locallogicalVolume- the logical volumedescription- the descriptionfsType- the filesystem typefreeSpace- free space in bytesusableSpace- usable space in bytestotalSpace- total space in bytesfreeInodes- free inodestotalInodes- total inodesfs- the parent filesystem
-
-
Method Details
-
updateAttributes
public boolean updateAttributes()Description copied from interface:OSFileStoreMake a best effort to update all the statistics about the file store without needing to recreate the file store list. This method provides for more frequent periodic updates of file store statistics.- Returns:
- True if the update was (probably) successful, false if the disk was not found
-