Uses of Class
oshi.software.common.os.linux.LinuxFileSystem
Packages that use LinuxFileSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
-
Uses of LinuxFileSystem in oshi.software.common.os.linux
Constructors in oshi.software.common.os.linux with parameters of type LinuxFileSystemModifierConstructorDescriptionLinuxOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes, LinuxFileSystem fs) Creates a LinuxOSFileStore. -
Uses of LinuxFileSystem in oshi.software.common.os.linux.nativefree
Subclasses of LinuxFileSystem in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux file system implementation.