Class LinuxNetworkParamsNF
java.lang.Object
oshi.software.common.AbstractNetworkParams
oshi.software.common.os.linux.LinuxNetworkParams
oshi.software.common.os.linux.nativefree.LinuxNetworkParamsNF
- All Implemented Interfaces:
NetworkParams
Native-free Linux network parameters implementation. Extends
LinuxNetworkParams, using the Java-based
hostname and domain name resolution from AbstractNetworkParams.-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class LinuxNetworkParams
getIpv4DefaultGateway, getIpv6DefaultGatewayModifier and TypeMethodDescriptionGets the default gateway(routing destination for 0.0.0.0/0) for IPv4 connections.Gets default gateway(routing destination for ::/0) for IPv6 connections.Methods inherited from class AbstractNetworkParams
getDnsServers, getDomainName, getHostName, searchGateway, toStringModifier and TypeMethodDescriptionString[]Gets the DNS Servers configured for this machine.Gets the Domain Name of the machine executing OSHI.Gets the HostName of the machine executing OSHI.protected static StringsearchGateway(List<String> lines) Convenience method to parse the output of the `route` command.toString()
-
Constructor Details
-
LinuxNetworkParamsNF
public LinuxNetworkParamsNF()
-