Class LinuxOperatingSystemNF
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.linux.LinuxOperatingSystem
oshi.software.common.os.linux.nativefree.LinuxOperatingSystemNF
- All Implemented Interfaces:
OperatingSystem
Native-free Linux operating system implementation. Extends
LinuxOperatingSystem, providing implementations
that require no native access.-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSorting -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected OSProcesscreateOSProcess(int pid) Creates an OS process for the given PID.Instantiates aFileSystemobject.longgetHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.Instantiates aNetworkParamsobject.longGets Page Size, for converting memory stats from pages to bytesgetProcess(int pid) Gets information on a currently running processintGets the current process ID (PID).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).static longhz()Gets Jiffies per second.static longpageSize()Gets Page Size in bytes.Methods inherited from class LinuxOperatingSystem
getBootTime, getCgroupInfo, getCurrentThread, getInstalledApplications, getInternetProtocolStats, getParentPidsFromProcFiles, getProcessCount, getReleaseFilename, getServices, getSystemBootTime, getSystemUptime, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryFamilyVersionInfo, queryManufacturerMethods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCurrentProcess, getProcesses, getProcesses
-
Constructor Details
-
LinuxOperatingSystemNF
public LinuxOperatingSystemNF()
-
-
Method Details
-
hz
public static long hz()Gets Jiffies per second.- Returns:
- Jiffies per second.
-
pageSize
public static long pageSize()Gets Page Size in bytes.- Returns:
- Page Size in bytes.
-
getHz
public long getHz()Description copied from class:LinuxOperatingSystemGets Jiffies per second, useful for converting ticks to milliseconds and vice versa.- Specified by:
getHzin classLinuxOperatingSystem- Returns:
- Jiffies per second.
-
getPageSize
public long getPageSize()Description copied from class:LinuxOperatingSystemGets Page Size, for converting memory stats from pages to bytes- Specified by:
getPageSizein classLinuxOperatingSystem- Returns:
- Page Size
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
createOSProcess
Description copied from class:LinuxOperatingSystemCreates an OS process for the given PID.- Specified by:
createOSProcessin classLinuxOperatingSystem- Parameters:
pid- the process ID- Returns:
- the OS process
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getThreadId
public int getThreadId()Description copied from interface:OperatingSystemMakes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.Thread IDs on macOS are not correlated with any other Operating System output.
- Returns:
- the Thread ID of the current thread if known, 0 otherwise.
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-