Class MacFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.mac.MacFileSystem
- All Implemented Interfaces:
FileSystem
Common constants and configuration for macOS file system implementations.
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected static final List<PathMatcher> protected static final List<PathMatcher> protected static final List<PathMatcher> protected static final List<PathMatcher> protected static final Patternprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intprotected static final intstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPES -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class AbstractFileSystem
getFileStoresMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface FileSystem
getFileStores, getMaxFileDescriptors, getMaxFileDescriptorsPerProcess, getOpenFileDescriptors
-
Field Details
-
OSHI_MAC_FS_PATH_EXCLUDES
- See Also:
-
OSHI_MAC_FS_PATH_INCLUDES
- See Also:
-
OSHI_MAC_FS_VOLUME_EXCLUDES
- See Also:
-
OSHI_MAC_FS_VOLUME_INCLUDES
- See Also:
-
FS_PATH_EXCLUDES
-
FS_PATH_INCLUDES
-
FS_VOLUME_EXCLUDES
-
FS_VOLUME_INCLUDES
-
LOCAL_DISK
-
MNT_RDONLY
protected static final int MNT_RDONLY- See Also:
-
MNT_SYNCHRONOUS
protected static final int MNT_SYNCHRONOUS- See Also:
-
MNT_NOEXEC
protected static final int MNT_NOEXEC- See Also:
-
MNT_NOSUID
protected static final int MNT_NOSUID- See Also:
-
MNT_NODEV
protected static final int MNT_NODEV- See Also:
-
MNT_UNION
protected static final int MNT_UNION- See Also:
-
MNT_ASYNC
protected static final int MNT_ASYNC- See Also:
-
MNT_CPROTECT
protected static final int MNT_CPROTECT- See Also:
-
MNT_EXPORTED
protected static final int MNT_EXPORTED- See Also:
-
MNT_QUARANTINE
protected static final int MNT_QUARANTINE- See Also:
-
MNT_LOCAL
protected static final int MNT_LOCAL- See Also:
-
MNT_QUOTA
protected static final int MNT_QUOTA- See Also:
-
MNT_ROOTFS
protected static final int MNT_ROOTFS- See Also:
-
MNT_DOVOLFS
protected static final int MNT_DOVOLFS- See Also:
-
MNT_DONTBROWSE
protected static final int MNT_DONTBROWSE- See Also:
-
MNT_IGNORE_OWNERSHIP
protected static final int MNT_IGNORE_OWNERSHIP- See Also:
-
MNT_AUTOMOUNTED
protected static final int MNT_AUTOMOUNTED- See Also:
-
MNT_JOURNALED
protected static final int MNT_JOURNALED- See Also:
-
MNT_NOUSERXATTR
protected static final int MNT_NOUSERXATTR- See Also:
-
MNT_DEFWRITE
protected static final int MNT_DEFWRITE- See Also:
-
MNT_MULTILABEL
protected static final int MNT_MULTILABEL- See Also:
-
MNT_NOATIME
protected static final int MNT_NOATIME- See Also:
-
OPTIONS_MAP
-
-
Constructor Details
-
MacFileSystem
public MacFileSystem()
-