Class MacOSFileStore
java.lang.Object
oshi.software.common.AbstractOSFileStore
oshi.software.common.os.mac.MacOSFileStore
- All Implemented Interfaces:
OSFileStore
Common base class for macOS OSFileStore implementations.
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedMacOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes) Creates a MacOSFileStore. -
Method Summary
Methods inherited from class AbstractOSFileStore
getDescription, getFreeInodes, getFreeSpace, getLabel, getLogicalVolume, getMount, getName, getOptions, getTotalInodes, getTotalSpace, getType, getUsableSpace, getUUID, getVolume, isLocal, toString, updateFrom, updateSpace, updateSpaceAndInodesMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OSFileStore
updateAttributes
-
Constructor Details
-
MacOSFileStore
protected MacOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes) Creates a MacOSFileStore.- Parameters:
name- the namevolume- the volumelabel- the labelmount- the mount pointoptions- the mount optionsuuid- the UUIDlocal- whether locallogicalVolume- the logical volumedescription- the descriptionfsType- the filesystem typefreeSpace- free space in bytesusableSpace- usable space in bytestotalSpace- total space in bytesfreeInodes- free inodestotalInodes- total inodes
-