Uses of Class
oshi.software.common.os.unix.openbsd.OpenBsdFileSystem
Packages that use OpenBsdFileSystem
Package
Description
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
-
Uses of OpenBsdFileSystem in oshi.software.common.os.unix.openbsd
Constructors in oshi.software.common.os.unix.openbsd with parameters of type OpenBsdFileSystemModifierConstructorDescriptionOpenBsdOSFileStore(OpenBsdFileSystem fileSystem, String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes)