Class SolarisOperatingSystem

java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.unix.solaris.SolarisOperatingSystem
All Implemented Interfaces:
OperatingSystem

@ThreadSafe public abstract class SolarisOperatingSystem extends AbstractOperatingSystem
Solaris is a non-free Unix operating system originally developed by Sun Microsystems. It superseded the company's earlier SunOS in 1993. In 2010, after the Sun acquisition by Oracle, it was renamed Oracle Solaris.

Process enumeration, services, and version queries are shared; the native bits (kstat uptime/boot time, getpid/thr_self, and the OSProcess/FileSystem/NetworkParams/OSThread factories) are provided by the JNA and FFM subclasses.