Class WindowsOSFileStore
java.lang.Object
oshi.software.common.AbstractOSFileStore
oshi.software.common.os.windows.WindowsOSFileStore
- All Implemented Interfaces:
OSFileStore
Common base class for Windows OSFileStore implementations.
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedWindowsOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes) Constructor. -
Method Summary
Methods inherited from class AbstractOSFileStore
getDescription, getFreeInodes, getFreeSpace, getLabel, getLogicalVolume, getMount, getName, getOptions, getTotalInodes, getTotalSpace, getType, getUsableSpace, getUUID, getVolume, isLocal, toString, updateFrom, updateSpace, updateSpaceAndInodesMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OSFileStore
updateAttributes
-
Constructor Details
-
WindowsOSFileStore
protected WindowsOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes) Constructor.- Parameters:
name- the namevolume- the volumelabel- the labelmount- the mountoptions- the optionsuuid- the uuidlocal- the locallogicalVolume- the logicalVolumedescription- the descriptionfsType- the fsTypefreeSpace- the freeSpaceusableSpace- the usableSpacetotalSpace- the totalSpacefreeInodes- the freeInodestotalInodes- the totalInodes
-