Class WindowsOSProcess

java.lang.Object
oshi.software.common.AbstractOSProcess
oshi.software.common.os.windows.WindowsOSProcess
All Implemented Interfaces:
OSProcess

@ThreadSafe public abstract class WindowsOSProcess extends AbstractOSProcess
Common base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.
  • Field Details

    • MAX_WINDOWS_HANDLES

      protected static final long MAX_WINDOWS_HANDLES
    • USE_BATCH_COMMANDLINE

      protected static final boolean USE_BATCH_COMMANDLINE
    • USE_PROCSTATE_SUSPENDED

      protected static final boolean USE_PROCSTATE_SUSPENDED
  • Constructor Details

  • Method Details

    • getOs

      protected OperatingSystem getOs()
      Returns the OperatingSystem instance associated with this process.
      Returns:
      the operating system instance
    • getCwdCmdEnv

      protected Triplet<String, String, Map<String,String>> getCwdCmdEnv()
      Returns the memoized CWD/CommandLine/Environment triplet.
      Returns:
      the triplet
    • getName

      public String getName()
      Description copied from interface: OSProcess
      Gets the name of the process, often the executable program.
      Returns:
      the name of the process.
    • getPath

      public String getPath()
      Description copied from interface: OSProcess
      Gets the full filesystem path of the executing process.
      Returns:
      the full path of the executing process.
    • getCommandLine

      public String getCommandLine()
      Description copied from interface: OSProcess
      Gets the process command line used to start the process, including arguments if available to be determined. This method generally returns the same information as OSProcess.getArguments() in a more user-readable format, and is more robust to non-elevated access.

      The format of this string is platform-dependent, may be truncated, and may require the end user to parse the result. Users should generally prefer OSProcess.getArguments() which already parses the results, and use this method as a backup.

      On AIX and Solaris, the string may be truncated to 80 characters if there was insufficient permission to read the process memory.

      On Windows, attempts to retrieve the value from process memory, which requires that the process be owned by the same user as the executing process, or elevated permissions, and additionally requires the target process to have the same bitness (e.g., this will fail on a 32-bit process if queried by 64-bit and vice versa). If reading process memory fails, by default, performs a single WMI query for this process, with some latency. If this method will be frequently called for multiple processes, see the configuration file to enable a batch query mode to improve performance via caching, or configure the option via GlobalConfig before instantiating any OSProcess object.

      Returns:
      the process command line.
    • getArguments

      public List<String> getArguments()
      Description copied from interface: OSProcess
      Makes a best effort attempt to get a list of the the command-line arguments of the process. Returns the same information as OSProcess.getCommandLine() but parsed to a list. May require elevated permissions or same-user ownership.
      Returns:
      A list of Strings representing the arguments. May return an empty list if there was a failure (for example, because the process is already dead or permission was denied).
    • getEnvironmentVariables

      public Map<String,String> getEnvironmentVariables()
      Description copied from interface: OSProcess
      Makes a best effort attempt to obtain the environment variables of the process. May require elevated permissions or same-user ownership.
      Returns:
      A map representing the environment variables and their values. May return an empty map if there was a failure (for example, because the process is already dead or permission was denied).
    • getCurrentWorkingDirectory

      public String getCurrentWorkingDirectory()
      Description copied from interface: OSProcess
      Makes a best effort attempt to obtain the current working directory for the process.
      Returns:
      the process current working directory.
    • getUser

      public String getUser()
      Description copied from interface: OSProcess
      Gets the user name of the process owner.
      Returns:
      the user name. On Windows systems, also returns the domain prepended to the username.
    • getUserID

      public String getUserID()
      Description copied from interface: OSProcess
      Gets the user id of the process owner.
      Returns:
      the userID. On Windows systems, returns the Security ID (SID)
    • getGroup

      public String getGroup()
      Description copied from interface: OSProcess
      Gets the group under which the process is executing.

      On Windows systems, populating this value for processes other than the current user requires administrative privileges (and still may fail for some system processes) and can incur significant latency. When successful, returns a the default primary group with access to this process, corresponding to the SID in OSProcess.getGroupID().

      Returns:
      the group.
    • getGroupID

      public String getGroupID()
      Description copied from interface: OSProcess
      Gets the group id under which the process is executing.

      On Windows systems, populating this value for processes other than the current user requires administrative privileges (and still may fail for some system processes) and can incur significant latency. When successful, returns the default primary group SID with access to this process, corresponding to the name in OSProcess.getGroup().

      Returns:
      the groupID.
    • getState

      public OSProcess.State getState()
      Description copied from interface: OSProcess
      Gets the process state.
      Returns:
      the execution state of the process.
    • getParentProcessID

      public int getParentProcessID()
      Description copied from interface: OSProcess
      Gets the process ID of this process's parent.
      Returns:
      the parentProcessID, if any; 0 otherwise.
    • getThreadCount

      public int getThreadCount()
      Description copied from interface: OSProcess
      Gets the number of threads being executed by this process. More information is available using OSProcess.getThreadDetails().
      Returns:
      the number of threads in this process.
    • getPriority

      public int getPriority()
      Description copied from interface: OSProcess
      Gets the priority of this process.

      For Linux and Unix, priority is a value in the range -20 to 19 (20 on some systems). The default priority is 0; lower priorities cause more favorable scheduling.

      For Windows, priority values can range from 0 (lowest priority) to 31 (highest priority).

      macOS has 128 priority levels, ranging from 0 (lowest priority) to 127 (highest priority). They are divided into several major bands: 0 through 51 are the normal levels; the default priority is 31. 52 through 79 are the highest priority regular threads; 80 through 95 are for kernel mode threads; and 96 through 127 correspond to real-time threads, which are treated differently than other threads by the scheduler.

      Returns:
      the priority of this process.
    • getVirtualSize

      public long getVirtualSize()
      Description copied from interface: OSProcess
      Gets the Virtual Memory Size (VSZ). Includes all memory that the process can access, including memory that is swapped out and memory that is from shared libraries.
      Returns:
      the Virtual Memory Size
    • getResidentMemory

      public long getResidentMemory()
      Description copied from interface: OSProcess
      Returns the total amount of physical memory (RAM) currently mapped to the process's address space. This value represents the Resident Set Size (RSS) and includes both private memory and memory shared with other processes (such as shared libraries). This aligns with the reporting behavior of standard command-line utilities like ps and top.

      On Linux, returns the RSS value from /proc/[pid]/stat, which may be inaccurate because of a kernel-internal scalability optimization. If accurate values are required, read /proc/[pid]/smaps using FileUtil#getKeyValueMapFromFile(String, String).

      Returns:
      The resident set size in bytes.
    • getPrivateResidentMemory

      public long getPrivateResidentMemory()
      Description copied from interface: OSProcess
      Returns an estimate of the portion of physical memory (RAM) uniquely attributed to this process. This metric excludes shared libraries and other memory segments mapped by multiple processes, providing a more accurate representation of the process's individual impact on system resources. This value aligns with the primary "Memory" column in graphical system monitors, such as Windows Task Manager, macOS Activity Monitor, and the GNOME System Monitor.
      Returns:
      The private or "footprint" resident memory in bytes if available. Defaults to OSProcess.getResidentMemory() otherwise.
    • getKernelTime

      public long getKernelTime()
      Description copied from interface: OSProcess
      Gets kernel/system (privileged) time used by the process.
      Returns:
      the number of milliseconds the process has executed in kernel/system mode.
    • getUserTime

      public long getUserTime()
      Description copied from interface: OSProcess
      Gets user time used by the process.
      Returns:
      the number of milliseconds the process has executed in user mode.
    • getUpTime

      public long getUpTime()
      Description copied from interface: OSProcess
      Gets up time / elapsed time since the process started.
      Returns:
      the number of milliseconds since the process started.
    • getStartTime

      public long getStartTime()
      Description copied from interface: OSProcess
      Gets the process start time.
      Returns:
      the start time of the process in number of milliseconds since January 1, 1970 UTC.
    • getBytesRead

      public long getBytesRead()
      Description copied from interface: OSProcess
      Gets the bytes read by the process. This includes all I/O activity generated by the process to include file, network, and device I/Os.

      On Solaris, includes both bytes read and written.

      Returns:
      the number of bytes the process has read.
    • getBytesWritten

      public long getBytesWritten()
      Description copied from interface: OSProcess
      Gets the bytes written by the process. This includes all I/O activity generated by the process to include file, network, and device I/Os.

      On Solaris, all IO bytes are included read bytes so this value is 0.

      Returns:
      the number of bytes the process has written to disk.
    • getOpenFiles

      public long getOpenFiles()
      Description copied from interface: OSProcess
      Gets the number of open file handles (or network connections) that belongs to the process.

      On FreeBSD and Solaris, this value is only populated if information for a single process id is requested.

      Returns:
      open files or -1 if unknown or not supported
    • getSoftOpenFileLimit

      public long getSoftOpenFileLimit()
      Description copied from interface: OSProcess
      Gets the soft limit for open file handles (or network connections) of the given process.

      Retrieving the soft limit for processes other than the calling process is only supported on Linux, FreeBsd and Solaris.

      Returns:
      the soft open file limit for the process if available. Returns -1 if the calling process is not the same as this OSProcess instance and the underlying operating system does not support retrieving the soft limit for other processes.
    • getHardOpenFileLimit

      public long getHardOpenFileLimit()
      Description copied from interface: OSProcess
      Gets the hard limit for open file handles (or network connections) that belong to the given process.

      Retrieving the hard limit for processes other than the calling process is only supported on Linux, FreeBsd and Solaris.

      Returns:
      the hard open file limit for the process if available. Returns -1 if the calling process is not the same as this OSProcess instance and the underlying operating system does not support retrieving the hard limit for other processes.
    • getBitness

      public int getBitness()
      Description copied from interface: OSProcess
      Attempts to get the bitness (32 or 64) of the process.
      Returns:
      The bitness, if able to be determined, 0 otherwise.
    • getMinorFaults

      public long getMinorFaults()
      Description copied from interface: OSProcess
      Gets the number of minor (soft) faults the process has made which have not required loading a memory page from disk. Sometimes called reclaims.

      On Windows, this includes the total of major and minor faults.

      Not available on AIX.

      Returns:
      minor page faults (reclaims).
    • getThreadDetails

      public List<OSThread> getThreadDetails()
      Description copied from interface: OSProcess
      Retrieves the threads of the process and their details.

      The amount of returned information is operating-system dependent and may incur some latency.

      Returns:
      a list of threads
    • createOSThread

      protected abstract OSThread createOSThread(int pid, int tid, String procName, ThreadPerfCounterBlock pcb)
      Creates a platform-specific OS thread instance.
      Parameters:
      pid - the owning process ID
      tid - the thread ID
      procName - the process name
      pcb - the thread performance counter block
      Returns:
      a new OSThread instance
    • updateAttributes

      protected boolean updateAttributes(ProcessPerfCounterBlock pcb, WtsInfo wts)
      Updates process attributes from performance counter and WTS data, then performs native-specific updates. Subclasses should call super.updateAttributes(pcb, wts) and then perform native handle-based updates.
      Parameters:
      pcb - Performance counter block for this process, or null if unavailable
      wts - WTS info for this process, or null if unavailable
      Returns:
      true if the process is valid after the update
    • setName

      protected void setName(String name)
      Sets the process name. Used by subclasses to ensure the name is current before querying threads.
      Parameters:
      name - the process name to set
    • setBitness

      protected void setBitness(int bitness)
      Sets the process bitness. Used by subclasses to update after WOW64 check.
      Parameters:
      bitness - the bitness to set
    • setPath

      protected void setPath(String path)
      Sets the process executable path. Used by subclasses to update after native query.
      Parameters:
      path - the path to set
    • setState

      protected void setState(OSProcess.State state)
      Sets the process state. Used by subclasses to mark a process as invalid.
      Parameters:
      state - the state to set
    • setTcb

      protected void setTcb(Map<Integer, ThreadPerfCounterBlock> tcb)
      Sets the thread counter block map. Used by subclasses during attribute updates.
      Parameters:
      tcb - the thread performance counter block map
    • queryMatchingThreads

      protected abstract Map<Integer, ThreadPerfCounterBlock> queryMatchingThreads(Set<Integer> pids)
      Queries thread performance data matching the given process IDs.
      Parameters:
      pids - the set of process IDs to match
      Returns:
      a map of thread ID to thread performance counter block
    • queryCommandLine

      protected abstract String queryCommandLine()
      Queries the command line for this process.
      Returns:
      the command line string
    • queryArguments

      protected abstract List<String> queryArguments()
      Queries the argument list for this process.
      Returns:
      the list of arguments
    • queryUserInfo

      protected abstract Pair<String,String> queryUserInfo()
      Queries user account information for this process.
      Returns:
      a pair of (account name, SID string)
    • queryGroupInfo

      protected abstract Pair<String,String> queryGroupInfo()
      Queries group account information for this process.
      Returns:
      a pair of (group name, SID string)
    • queryCwdCommandlineEnvironment

      protected abstract Triplet<String, String, Map<String,String>> queryCwdCommandlineEnvironment()
      Queries the current working directory, command line, and environment variables from process memory.
      Returns:
      a triplet of (cwd, commandLine, environmentVariables)
    • defaultCwdCommandlineEnvironment

      protected static Triplet<String, String, Map<String,String>> defaultCwdCommandlineEnvironment()
    • defaultPair

      protected static Pair<String,String> defaultPair()