Enum Class InternetProtocolStats.TcpState
- All Implemented Interfaces:
Serializable, Comparable<InternetProtocolStats.TcpState>, Constable
- Enclosing interface:
InternetProtocolStats
@PublicApi
public static enum InternetProtocolStats.TcpState
extends Enum<InternetProtocolStats.TcpState>
The TCP connection state as described in RFC 793.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionWaiting for a connection termination request from the local user.Connection closed.Waiting for acknowledgment of a connection termination request.Connection established.Waiting for a connection termination request from the remote TCP.Waiting for a connection termination request from the remote TCP after sending one.Waiting for acknowledgment of the connection termination request sent to the remote TCP.Waiting for a connection request.No state.Waiting for acknowledgment of a connection request after having received one.Waiting for acknowledgment of a connection request.Waiting for enough time to pass to be sure the remote TCP received acknowledgment.Unknown state. -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static InternetProtocolStats.TcpState[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
UNKNOWN
Unknown state. -
CLOSED
Connection closed. -
LISTEN
Waiting for a connection request. -
SYN_SENT
Waiting for acknowledgment of a connection request. -
SYN_RECV
Waiting for acknowledgment of a connection request after having received one. -
ESTABLISHED
Connection established. -
FIN_WAIT_1
Waiting for a connection termination request from the remote TCP. -
FIN_WAIT_2
Waiting for a connection termination request from the remote TCP after sending one. -
CLOSE_WAIT
Waiting for a connection termination request from the local user. -
CLOSING
Waiting for acknowledgment of a connection termination request. -
LAST_ACK
Waiting for acknowledgment of the connection termination request sent to the remote TCP. -
TIME_WAIT
Waiting for enough time to pass to be sure the remote TCP received acknowledgment. -
NONE
No state.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-