Uses of Class
oshi.software.os.ApplicationInfo
Packages that use ApplicationInfo
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
Uses of ApplicationInfo in oshi.software.common.os.linux
Methods in oshi.software.common.os.linux that return types with arguments of type ApplicationInfoModifier and TypeMethodDescriptionLinuxOperatingSystem.getInstalledApplications()static List<ApplicationInfo> LinuxInstalledApps.queryInstalledApps()Retrieves the list of installed applications on a Linux system. -
Uses of ApplicationInfo in oshi.software.common.os.mac
Methods in oshi.software.common.os.mac that return types with arguments of type ApplicationInfoModifier and TypeMethodDescriptionMacOperatingSystem.getInstalledApplications()static List<ApplicationInfo> MacInstalledApps.queryInstalledApps()Queries installed applications. -
Uses of ApplicationInfo in oshi.software.common.os.unix.aix
Methods in oshi.software.common.os.unix.aix that return types with arguments of type ApplicationInfoModifier and TypeMethodDescriptionstatic List<ApplicationInfo> AixInstalledApps.queryInstalledApps() -
Uses of ApplicationInfo in oshi.software.os
Methods in oshi.software.os that return types with arguments of type ApplicationInfoModifier and TypeMethodDescriptiondefault List<ApplicationInfo> OperatingSystem.getInstalledApplications()Retrieves a list of installed applications on the system.