Uses of Interface
oshi.software.os.FileSystem
Packages that use FileSystem
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides utilities for parsing, formatting, and other access
-
Uses of FileSystem in oshi.software.common
Classes in oshi.software.common that implement FileSystemModifier and TypeClassDescriptionclassCommon methods for filesystem implementations -
Uses of FileSystem in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement FileSystemModifier and TypeClassDescriptionclassThe Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of FileSystem in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement FileSystemModifier and TypeClassDescriptionclassCommon constants and configuration for macOS file system implementations. -
Uses of FileSystem in oshi.software.os
Methods in oshi.software.os that return FileSystemModifier and TypeMethodDescriptionOperatingSystem.getFileSystem()Instantiates aFileSystemobject. -
Uses of FileSystem in oshi.util
Methods in oshi.util with parameters of type FileSystemModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printFileSystem(List<String> lines, FileSystem fileSystem)