Uses of Class
oshi.software.os.OSDesktopWindow
Packages that use OSDesktopWindow
Package
Description
Provides abstract classes for common code
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides driver utilities common to unix systems that do not require native access
-
Uses of OSDesktopWindow in oshi.software.common
Methods in oshi.software.common that return types with arguments of type OSDesktopWindow -
Uses of OSDesktopWindow in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSDesktopWindowModifier and TypeMethodDescriptiondefault List<OSDesktopWindow> OperatingSystem.getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop. -
Uses of OSDesktopWindow in oshi.util.driver.unix
Methods in oshi.util.driver.unix that return types with arguments of type OSDesktopWindowModifier and TypeMethodDescriptionstatic List<OSDesktopWindow> Xwininfo.queryXWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.