Uses of Interface
oshi.software.os.OSFileStore
Packages that use OSFileStore
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
Uses of OSFileStore in oshi.software.common
Classes in oshi.software.common that implement OSFileStoreModifier and TypeClassDescriptionclassCommon implementations for OSFileStoreMethods in oshi.software.common that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement OSFileStoreMethods in oshi.software.common.os.linux that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement OSFileStoreModifier and TypeClassDescriptionclassCommon OSFileStore fields and getters for macOS implementations.Methods in oshi.software.common.os.mac with parameters of type OSFileStoreModifier and TypeMethodDescriptionprotected voidMacOSFileStore.updateFrom(OSFileStore fileStore) Copies attributes from another file store into this one. -
Uses of OSFileStore in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows that implement OSFileStoreModifier and TypeClassDescriptionclassCommon base class for Windows OSFileStore implementations, containing shared fields and getters.Methods in oshi.software.common.os.windows with parameters of type OSFileStoreModifier and TypeMethodDescriptionprotected voidWindowsOSFileStore.updateFrom(OSFileStore fileStore) Sets fields from a matching file store during attribute updates. -
Uses of OSFileStore in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSFileStoreModifier and TypeMethodDescriptionFileSystem.getFileStores()Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.FileSystem.getFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.