Uses of Interface
oshi.software.os.OSProcess

Packages that use OSProcess
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information