Uses of Class
oshi.software.os.OSService
Packages that use OSService
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
Uses of OSService in oshi.software.common.os.linux
Methods in oshi.software.common.os.linux that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.mac
Methods in oshi.software.common.os.mac that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.unix.netbsd
Methods in oshi.software.common.os.unix.netbsd that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.unix.solaris
Methods in oshi.software.common.os.unix.solaris that return types with arguments of type OSService -
Uses of OSService in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSServiceModifier and TypeMethodDescriptionOperatingSystem.getServices()Gets the all services on the system.