Uses of Interface
oshi.software.os.OSThread
Packages that use OSThread
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides shared abstract base classes for the
/proc-filesystem Unix operating systemsProvides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
Uses of OSThread in oshi.software.common
Classes in oshi.software.common that implement OSThreadModifier and TypeClassDescriptionclassCommon methods for OSThread implementationMethods in oshi.software.common with parameters of type OSThreadModifier and TypeMethodDescriptiondoubleAbstractOSThread.getThreadCpuLoadBetweenTicks(OSThread priorSnapshot) -
Uses of OSThread in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement OSThreadMethods in oshi.software.common.os.linux that return OSThreadMethods in oshi.software.common.os.linux that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement OSThreadMethods in oshi.software.common.os.mac that return OSThreadMethods in oshi.software.common.os.mac that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix
Methods in oshi.software.common.os.unix that return OSThreadModifier and TypeMethodDescriptionprotected abstract OSThreadAbstractProcOSProcess.createThread(int lwpid) Creates a platform-specificOSThreadfor the given lwpid of this process.Methods in oshi.software.common.os.unix that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix.aix
Classes in oshi.software.common.os.unix.aix that implement OSThreadMethods in oshi.software.common.os.unix.aix that return OSThread -
Uses of OSThread in oshi.software.common.os.unix.bsd
Classes in oshi.software.common.os.unix.bsd that implement OSThreadModifier and TypeClassDescriptionclassAbstract base shared by the BSD-family OSThread implementations (FreeBSD, OpenBSD, DragonFly, NetBSD). -
Uses of OSThread in oshi.software.common.os.unix.dragonflybsd
Classes in oshi.software.common.os.unix.dragonflybsd that implement OSThreadMethods in oshi.software.common.os.unix.dragonflybsd that return OSThreadMethods in oshi.software.common.os.unix.dragonflybsd that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix.freebsd
Classes in oshi.software.common.os.unix.freebsd that implement OSThreadMethods in oshi.software.common.os.unix.freebsd that return OSThreadMethods in oshi.software.common.os.unix.freebsd that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix.netbsd
Classes in oshi.software.common.os.unix.netbsd that implement OSThreadMethods in oshi.software.common.os.unix.netbsd that return OSThreadMethods in oshi.software.common.os.unix.netbsd that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix.openbsd
Classes in oshi.software.common.os.unix.openbsd that implement OSThreadMethods in oshi.software.common.os.unix.openbsd that return OSThreadMethods in oshi.software.common.os.unix.openbsd that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.common.os.unix.solaris
Classes in oshi.software.common.os.unix.solaris that implement OSThread -
Uses of OSThread in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows that implement OSThreadModifier and TypeClassDescriptionclassCommon base class for Windows OS thread implementations.Methods in oshi.software.common.os.windows that return OSThreadModifier and TypeMethodDescriptionprotected abstract OSThreadWindowsOSProcess.createOSThread(int pid, int tid, String procName, ThreadPerfCounterBlock pcb) Creates a platform-specific OS thread instance.Methods in oshi.software.common.os.windows that return types with arguments of type OSThread -
Uses of OSThread in oshi.software.os
Fields in oshi.software.os with type parameters of type OSThreadModifier and TypeFieldDescriptionOSThread.ThreadFiltering.VALID_THREADExclude processes withOSProcess.State.INVALIDprocess state.Methods in oshi.software.os that return OSThreadModifier and TypeMethodDescriptionOperatingSystem.getCurrentThread()Makes a best effort to get the current thread.Methods in oshi.software.os that return types with arguments of type OSThreadModifier and TypeMethodDescriptionOSProcess.getThreadDetails()Retrieves the threads of the process and their details.Methods in oshi.software.os with parameters of type OSThreadModifier and TypeMethodDescriptiondoubleOSThread.getThreadCpuLoadBetweenTicks(OSThread thread) Gets CPU usage of this thread since a previous snapshot of the same thread, provided as a parameter.