Package oshi.software.os
package oshi.software.os
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
ClassDescriptionRepresents common information about an installed application across different operating systems.Represents cgroup (control group) information for containerized environments.The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.Encapsulates information associated with an IP connection.The TCP connection state as described in RFC 793.Encapsulates statistics associated with a TCP connection.Encapsulates statistics associated with a UDP connection.Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.A class representing the Operating System version details.Constants which may be used to filter Process lists in
OperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).Constants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).This class encapsulates information about a window on the operating system's GUI desktop.A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Represents a Process on the operating system, which may contain multiple threads.Process and Thread Execution StatesOperating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.Service Execution StatesThis class encapsulates information about users who are currently logged in to an operating system.Represents a Thread/Task on the operating system.Constants which may be used to filter Thread lists