Uses of Package
oshi.software.os

Packages that use oshi.software.os
Package
Description
Provides functions to query Mac info
Native-free OSHI entry point for Linux.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access
Provides non-native Linux driver utilities for querying system information.
Provides non-native Linux driver utilities for querying the /proc filesystem.
Provides driver utilities common to unix systems that do not require native access
  • Class
    Description
    Process and Thread Execution States
  • Class
    Description
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates information associated with an IP connection.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A class representing the Operating System version details.
    This class encapsulates information about a window on the operating system's GUI desktop.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    This class encapsulates information about users who are currently logged in to an operating system.
    Represents a Thread/Task on the operating system.
  • Class
    Description
    Represents common information about an installed application across different operating systems.
    Represents cgroup (control group) information for containerized environments.
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates information associated with an IP connection.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A class representing the Operating System version details.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    Represents a Thread/Task on the operating system.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    Represents a Process on the operating system, which may contain multiple threads.
  • Class
    Description
    Represents common information about an installed application across different operating systems.
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    Represents a Thread/Task on the operating system.
  • Class
    Description
    Represents common information about an installed application across different operating systems.
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Represents a Thread/Task on the operating system.
  • Class
    Description
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
  • Class
    Description
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Represents a Thread/Task on the operating system.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Represents a Thread/Task on the operating system.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A class representing the Operating System version details.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    Represents a Thread/Task on the operating system.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Represents a Thread/Task on the operating system.
  • Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A class representing the Operating System version details.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    Represents a Thread/Task on the operating system.
  • Class
    Description
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Represents a Thread/Task on the operating system.
  • Class
    Description
    Represents common information about an installed application across different operating systems.
    Represents cgroup (control group) information for containerized environments.
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Encapsulates information associated with an IP connection.
    The TCP connection state as described in RFC 793.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    A class representing the Operating System version details.
    This class encapsulates information about a window on the operating system's GUI desktop.
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    Represents a Process on the operating system, which may contain multiple threads.
    Process and Thread Execution States
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    Service Execution States
    This class encapsulates information about users who are currently logged in to an operating system.
    Represents a Thread/Task on the operating system.
  • Classes in oshi.software.os used by oshi.spi
    Class
    Description
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
  • Classes in oshi.software.os used by oshi.util
    Class
    Description
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
    Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
  • Class
    Description
    This class encapsulates information about users who are currently logged in to an operating system.
  • Class
    Description
    Process and Thread Execution States
  • Class
    Description
    Encapsulates information associated with an IP connection.
    Encapsulates statistics associated with a TCP connection.
    Encapsulates statistics associated with a UDP connection.
    This class encapsulates information about a window on the operating system's GUI desktop.
    This class encapsulates information about users who are currently logged in to an operating system.