Class Who

java.lang.Object
oshi.util.driver.linux.Who

@ThreadSafe public final class Who extends Object
Utility to query logged in users using the who command with Linux date format parsing, falling back to Unix format.
  • Method Details

    • queryWho

      public static List<OSSession> queryWho()
      Query who to get logged in users, trying Linux date format first, then Unix format.
      Returns:
      A list of logged in user sessions