Interface Auxv.NativeLongReader

Enclosing class:
Auxv
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface Auxv.NativeLongReader
Reads a native-long value from a ByteBuffer and returns it as a Java long.
  • Method Summary

    Modifier and Type
    Method
    Description
    long
    read(ByteBuffer buffer)
    Reads the next native-long value from the buffer.
  • Method Details

    • read

      long read(ByteBuffer buffer)
      Reads the next native-long value from the buffer.
      Parameters:
      buffer - the buffer to read from
      Returns:
      the value as a Java long