Enum Class ProcessStat.PidStatM
- All Implemented Interfaces:
Serializable, Comparable<ProcessStat.PidStatM>, Constable
- Enclosing class:
ProcessStat
Enum corresponding to the fields in the output of
/proc/[pid]/statm-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionstatic ProcessStat.PidStatMReturns the enum constant of this class with the specified name.static ProcessStat.PidStatM[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
SIZE
Total program size -
RESIDENT
Resident set size -
SHARED
Number of resident shared pages (i.e., backed by a file) -
TEXT
Text (code) -
LIB
Library (unused since Linux 2.6; always 0) -
DATA
Data + stack -
DT
Dirty pages (unused since Linux 2.6; always 0)
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-