Uses of Enum Class
oshi.util.driver.linux.proc.ProcessStat.PidStat
Packages that use ProcessStat.PidStat
Package
Description
Provides non-native Linux driver utilities for querying the
/proc filesystem.-
Uses of ProcessStat.PidStat in oshi.util.driver.linux.proc
Subclasses with type arguments of type ProcessStat.PidStat in oshi.util.driver.linux.procModifier and TypeClassDescriptionstatic enumEnum corresponding to the fields in the output of/proc/[pid]/statMethods in oshi.util.driver.linux.proc that return ProcessStat.PidStatModifier and TypeMethodDescriptionstatic ProcessStat.PidStatReturns the enum constant of this class with the specified name.static ProcessStat.PidStat[]ProcessStat.PidStat.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.util.driver.linux.proc that return types with arguments of type ProcessStat.PidStatModifier and TypeMethodDescriptionProcessStat.getPidStats(int pid) Reads the statistics in/proc/[pid]/statand returns the results.