Uses of Enum Class
oshi.util.driver.linux.proc.ProcessStat.PidStatM
Packages that use ProcessStat.PidStatM
Package
Description
Provides non-native Linux driver utilities for querying the
/proc filesystem.-
Uses of ProcessStat.PidStatM in oshi.util.driver.linux.proc
Subclasses with type arguments of type ProcessStat.PidStatM in oshi.util.driver.linux.procModifier and TypeClassDescriptionstatic enumEnum corresponding to the fields in the output of/proc/[pid]/statmMethods in oshi.util.driver.linux.proc that return ProcessStat.PidStatMModifier and TypeMethodDescriptionstatic ProcessStat.PidStatMReturns the enum constant of this class with the specified name.static ProcessStat.PidStatM[]ProcessStat.PidStatM.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.util.driver.linux.proc that return types with arguments of type ProcessStat.PidStatMModifier and TypeMethodDescriptionstatic Map<ProcessStat.PidStatM, Long> ProcessStat.getPidStatM(int pid) Reads the statistics in/proc/[pid]/statmand returns the results.