All Classes and Interfaces

Class
Description
Baseboard data
Abstract base class for BluetoothDevice implementations.
A CPU.
Computer System data.
A Display
Common methods for filesystem implementations
Firmware data.
Memory info.
An abstract Graphics Card
Common fields or methods used by platform-specific implementations of HardwareAbstractionLayer
Common methods for platform HWDiskStore classes
Common implementations for IP Stats
Common implementations for LogicalVolumeGroup.
Network interfaces implementation.
Common NetworkParams implementation.
Common methods for OperatingSystem implementations
Common implementations for OSFileStore
A process is an instance of a computer program that is being executed.
Common methods for OSThread implementation
A Power Source
Abstract base class for Printer implementations.
Sensors from WMI or Open Hardware Monitor
An abstract Sound Card
A USB device
Virtual Memory info.
Represents common information about an installed application across different operating systems.
Constants and shared logic for the Linux auxiliary vector (/proc/self/auxv).
Reads a native-long value from a ByteBuffer and returns it as a Java long.
The Baseboard represents the system board, also called motherboard, logic board, etc.
Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
A class representing CPU Cache Memory.
The type of cache.
A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
Represents cgroup (control group) information for containerized environments.
The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
General constants used in multiple classes
Utility to read CPU info from /proc/cpuinfo
Utility to read CPU statistics from /proc/stat
CUPS-based printer implementation with shared lpstat fallback logic.
Factory interface for creating concrete printer instances.
Utility to read info from the devicetree
Provides constants for paths in the /dev filesystem on Linux.
Utility to read disk statistics from /proc/diskstats
Enum corresponding to the fields in the output of /proc/diskstats
Display refers to the information regarding a video source and monitor identified by the EDID standard.
Utility to read info from dmidecode
Utility to read EDID data from the Linux DRM (Direct Rendering Manager) subsystem.
Immutable snapshot of a DXGI adapter's identity and dedicated video memory.
Shared utility methods for DXGI adapter matching and related parsing.
EDID parsing utility.
Utility methods for reducing repetitive exception handling boilerplate, particularly around FFM (Foreign Function and Memory) native calls that require catching Throwable.
A boolean-returning supplier that may throw any Throwable.
A double-returning supplier that may throw any Throwable.
An int-returning supplier that may throw any Throwable.
A long-returning supplier that may throw any Throwable.
A runnable that may throw any Throwable.
A supplier that may throw any Throwable, including checked exceptions.
A class for executing on the command line and returning the result of execution.
The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
Utility class for common filesystem code
File reading methods
The Firmware represents the low level BIOS or equivalent.
Formatting utility for appending units or converting between number types.
The global configuration utility.
Indicates that a configuration value is invalid.
The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
GPU performance counter enums.
GPU Adapter Memory counter properties.
GPU Engine running time counter properties.
A session handle for sampling dynamic GPU metrics.
An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
Represents a graphics card (GPU) installed in the system.
The field or method to which this annotation is applied can only be accessed when holding a particular lock, which may be a built-in (synchronization) lock, or may be an explicit java.util.concurrent.Lock.
A hardware abstraction layer.
Base class for HKEY_PERFORMANCE_DATA utilities.
A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
The presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.
Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
Encapsulates information associated with an IP connection.
The TCP connection state as described in RFC 793.
Encapsulates statistics associated with a TCP connection.
Encapsulates statistics associated with a UDP connection.
Abstracts IOKit registry operations so that iteration logic can be shared between JNA and FFM implementations.
A handle to an IORegistry entry, providing property access.
Constants, property enums, and WHERE clause builders for LibreHardwareMonitor WMI sensor data.
LHM Hardware properties.
Sensor properties returned by LHM WMI queries.
Linux Bluetooth device enumeration via BlueZ filesystem paths.
A CPU as defined in Linux /proc.
Native-free Linux central processor implementation.
Linux implementation of CgroupInfo supporting both cgroup v2 and v1.
The Linux File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Native-free Linux file system implementation.
Memory obtained by /proc/meminfo and sysinfo.totalram
Linux GpuStats session.
Graphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.
Parsed graphics card attributes used to construct concrete subclass instances.
LinuxHardwareAbstractionLayer class.
Native-free hardware abstraction layer for Linux.
Linux hard disk implementation.
Field ordering in udev stat output.
Native-free Linux disk store implementation.
Utility class for querying installed applications on Linux.
Internet Protocol Stats implementation
Linux implementation of LogicalVolumeGroup.
LinuxNetworks class.
Native-free Linux network interface implementation.
Linux network parameters.
Native-free Linux network parameters implementation.
Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.
Native-free Linux operating system implementation.
OSFileStore implementation
OSProcess implementation
Native-free Linux OS process implementation.
OSThread implementation
A Power Source
Power supply uevent properties from sysfs.
Linux USB device base class.
Native-free Linux USB device enumeration from /sys/bus/usb/devices/.
Utility to calculate a load average equivalent metric on Windows.
A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
Utility to parse printer information from lpstat and lpoptions commands.
Utility to read info from lshal
Utility to read info from lshw
Baseboard data obtained from ioreg
macOS Bluetooth device enumeration via system_profiler SPBluetoothDataType.
Base class for macOS CentralProcessor implementations.
Hardware data obtained from ioreg.
Common constants and configuration for macOS file system implementations.
Firmware data obtained from ioreg.
Memory obtained by host_statistics (vm_stat) and sysctl.
Graphics card info obtained by system_profiler SPDisplaysDataType.
Factory for creating GraphicsCard instances.
Functional interface for sysctl long queries.
MacHardwareAbstractionLayer class.
Base class for macOS HWDiskStore implementations.
Strings to convert to CFStringRef for pointer lookups.
Utility class for querying installed applications on macOS.
MacLogicalVolumeGroup class.
Base class for macOS NetworkIF implementations.
macOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.
Common base class for macOS OSFileStore implementations.
OSThread implementation
A Power Source
Sound card data obtained via AppleHDA kext
Mac USB device base class.
Memory obtained by host_statistics (vm_stat) and sysctl.
A memoized function stores the output corresponding to some set of specific inputs.
Memory performance counter enums
For pages in/out
Constants and property enum for WMI class MSAcpi_ThermalZoneTemperature.
Current temperature property.
Constants and property enums for WMI classes in the Storage namespace associated with Storage Pools.
Properties for a physical disk.
Properties to identify the storage pool.
Properties to link a storage pool with a physical disk.
Properties for a virtual disk.
Utility to query TCP connections
A network interface in the machine, including statistics.
The current operational state of a network interface.
Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
A no-op GpuStats implementation returned by platforms that do not support a native stats session.
The presence of this annotation indicates that the author believes the class is not thread-safe.
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Hardware data.
HW Identifier Property.
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Sensor data.
Sensor value property.
An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
A class representing the Operating System version details.
This class encapsulates information about a window on the operating system's GUI desktop.
A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Represents a Process on the operating system, which may contain multiple threads.
Process and Thread Execution States
Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
Service Execution States
This class encapsulates information about users who are currently logged in to an operating system.
Represents a Thread/Task on the operating system.
Constants which may be used to filter Thread lists
Paging File performance counter enums
For swap file usage
Convenience class for returning multiple objects from methods.
String parsing utility.
Contract for Counter Property Enums.
Contract for Wildcard Counter Property Enums.
Encapsulates the three string components of a PDH performance counter path, plus whether it refers to the base (SecondValue) of a multi-value counter.
Common interface for querying Windows performance counters, abstracting JNA and FFM implementations.
Constants used in Perfmon driver classes
Physical Disk performance counter enums
Physical Disk performance counters.
The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
An enumeration of supported operating systems.
A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
Units of Battery Capacity
Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
Printer status enumeration.
Utility class for privileged command execution and file reading.
Process performance counter enums
Handle performance counters
Processor performance counters
Process performance counters
Processor performance counter enums
System interrupts counters
Processor Frequency counters.
Processor Performance counters from the WMI Formatted Data table.
Processor performance counters
Processor performance counters including utility counters
System performance counters
Encapsulates process performance data from the registry performance counter block.
Common logic for building process performance data maps from registry or performance counter results.
Utility to read process statistics from /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/statm
Provides constants for paths in the /proc filesystem on Linux.
Utility class for parsing /proc filesystem statistics.
Indicates that the annotated type is part of the OSHI public API.
Convenience class for returning multiple objects from methods.
Convenience class for returning multiple objects from methods.
Sensors include hardware sensors to monitor temperature, fan speed, and other information.
Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
This annotation exists to permit suppression in the Forbidden APIs check and also indicate to consumers of these classes that they may need to handle these differently in their production code.
Abstracts sysctl operations so that Mac base classes can query sysctl values without depending on JNA or FFM directly.
Utility to read info from sysfs
Provides constants for paths in the /sys filesystem on Linux.
Native-free SystemInfoProvider for Linux.
Factory that uses ServiceLoader to discover and select the best available SystemInfoProvider.
Static helper methods for printing OSHI system information, shared across test modules.
Service Provider Interface for OSHI's SystemInfo entry points.
System performance counter enums
Context switch property
Processor Queue Length property
Utility to query threads for a process
Class to encapsulate mach thread info
Thread performance counter enums
Thread performance counters
Encapsulates thread performance data from the registry performance counter block.
Common logic for building thread performance data maps from registry or performance counter results.
The presence of this annotation indicates that the author believes the class to be thread-safe.
Convenience class for returning multiple objects from methods.
A Display
Utility to read system uptime from /proc/uptime
A USB device is a device connected via a USB port, possibly internally/permanently.
Utility class to temporarily cache the userID and group maps in *nix, for parsing process ownership.
General utility methods
The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
Utility to query logged in users using the who command with Linux date format parsing, falling back to Unix format.
Utility to query logged in users using the who command with Unix date format parsing.
Constants and property enum for WMI class Win32_BaseBoard.
Baseboard description properties.
Constants and property enums for WMI class Win32_BIOS.
BIOS description properties.
Serial number property.
Constants and property enum for WMI class Win32_ComputerSystem.
Computer System properties.
Constants and property enum for WMI class Win32_ComputerSystemProduct.
Computer System ID number.
Constants and property enum for WMI class Win32_DiskDrive.
Disk drive properties.
Constants and property enum for WMI class Win32_DiskDriveToDiskPartition.
Links disk drives to partitions.
Constants and property enum for WMI class Win32_DiskPartition.
Disk partition properties.
Constants and property enum for WMI class Win32_Fan.
Fan speed property.
Constants and property enum for WMI class Win32_LogicalDisk.
Logical disk properties.
Constants and property enum for WMI class Win32_LogicalDiskToPartition.
Links disk drives to partitions.
Constants and property enum for WMI class Win32_OperatingSystem.
Operating System properties.
Constants and property enums for WMI class Win32_PhysicalMemory.
Physical Memory properties for Win10 and later.
Physical Memory properties for Win8 and earlier.
Constants and property enum for WMI class Win32_Printer.
Printer properties from WMI.
Constants, property enums, and WHERE clause builder for WMI class Win32_Process.
Process command lines.
Process properties accessible from WTSEnumerateProcesses in Vista+.
Constants and property enums for WMI class Win32_Processor.
Processor bitness property.
Processor ID property.
Processor voltage properties.
Constants and property enum for WMI class Win32_VideoController.
Video Controller properties.
Baseboard data obtained from WMI.
Common non-native logic for Windows Central Processor implementations.
Hardware data obtained from WMI.
Firmware data obtained from WMI.
Common Windows global memory logic shared between JNA and FFM implementations.
Common Windows GpuStats implementation.
Common Windows hard disk implementation shared between JNA and FFM.
Maps to store read/write bytes per drive index
Maps for the partition structure
Common base class for Windows operating system implementations.
Common base class for Windows OSFileStore implementations.
Common base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.
Common base class for Windows OS thread implementations.
A Power Source
Common Windows printer logic shared between JNA and FFM implementations.
WMI type constants used for interpreting WmiResult values.
Encapsulates a WMI query with a namespace, class name, and property enum.
Common interface for executing WMI queries, abstracting JNA and FFM implementations.
Common interface for WMI query results, abstracting JNA and FFM implementations.
Helper class for extracting typed values from WmiResult objects.
Data holder for Windows Terminal Services (WTS) process information.
Utility to query xrandr
Utility to query X11 windows