Enum Class ThreadInformation.ThreadPerformanceProperty
java.lang.Object
java.lang.Enum<ThreadInformation.ThreadPerformanceProperty>
oshi.driver.common.windows.perfmon.ThreadInformation.ThreadPerformanceProperty
- All Implemented Interfaces:
Serializable, Comparable<ThreadInformation.ThreadPerformanceProperty>, Constable, PdhCounterWildcardProperty
- Enclosing class:
ThreadInformation
public static enum ThreadInformation.ThreadPerformanceProperty
extends Enum<ThreadInformation.ThreadPerformanceProperty>
implements PdhCounterWildcardProperty
Thread performance counters
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescription -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
NAME
-
PERCENTUSERTIME
-
PERCENTPRIVILEGEDTIME
-
ELAPSEDTIME
-
PRIORITYCURRENT
-
STARTADDRESS
-
THREADSTATE
-
THREADWAITREASON
-
IDPROCESS
-
IDTHREAD
-
CONTEXTSWITCHESPERSEC
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getCounter
- Specified by:
getCounterin interfacePdhCounterWildcardProperty- Returns:
- Returns the counter. The first element of the enum will return the instance filter rather than a counter.
-