Uses of Class
oshi.hardware.CentralProcessor.LogicalProcessor
Packages that use CentralProcessor.LogicalProcessor
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of CentralProcessor.LogicalProcessor in oshi.hardware
Methods in oshi.hardware that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionCentralProcessor.getLogicalProcessors()Returns anUnmodifiableListof the CPU's logical processors. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common
Methods in oshi.hardware.common that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionAbstractCentralProcessor.getLogicalProcessors()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AbstractCentralProcessor.initProcessorCounts()Initializes logical and physical processor lists and feature flags.Method parameters in oshi.hardware.common with type arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected List<CentralProcessor.PhysicalProcessor> AbstractCentralProcessor.createProcListFromDmesg(List<CentralProcessor.LogicalProcessor> logProcs, Map<Integer, String> dmesg) -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected static CentralProcessor.LogicalProcessorLinuxCentralProcessor.getLogicalProcessorFromSyspath(String syspath, Set<CentralProcessor.ProcessorCache> caches, String modAlias, Map<Integer, Integer> coreEfficiencyMap, Map<Integer, String> modAliasMap) Methods in oshi.hardware.common.platform.linux that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> LinuxCentralProcessor.initProcessorCounts()protected static Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyFromSysfs()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyWithUdev()Reads CPU topology using udev. -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return types with arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> MacCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.LogicalProcessor in oshi.hardware.common.platform.windows
Method parameters in oshi.hardware.common.platform.windows with type arguments of type CentralProcessor.LogicalProcessorModifier and TypeMethodDescriptionprotected voidWindowsCentralProcessor.buildNumaNodeProcMap(List<CentralProcessor.LogicalProcessor> logProcs) Builds the numaNodeProcToLogicalProcMap from the logical processor list.