Uses of Class
oshi.hardware.CentralProcessor.ProcessorCache
Packages that use CentralProcessor.ProcessorCache
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
-
Uses of CentralProcessor.ProcessorCache in oshi.hardware
Methods in oshi.hardware that return types with arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionCentralProcessor.getProcessorCaches()Makes a best-effort attempt to identify the CPU's processor caches. -
Uses of CentralProcessor.ProcessorCache in oshi.hardware.common
Methods in oshi.hardware.common that return types with arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionAbstractCentralProcessor.getProcessorCaches()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AbstractCentralProcessor.initProcessorCounts()Initializes logical and physical processor lists and feature flags.static List<CentralProcessor.ProcessorCache> AbstractCentralProcessor.orderedProcCaches(Set<CentralProcessor.ProcessorCache> caches) Filters a set of processor caches to an ordered listMethod parameters in oshi.hardware.common with type arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionstatic List<CentralProcessor.ProcessorCache> AbstractCentralProcessor.orderedProcCaches(Set<CentralProcessor.ProcessorCache> caches) Filters a set of processor caches to an ordered list -
Uses of CentralProcessor.ProcessorCache in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return types with arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> LinuxCentralProcessor.initProcessorCounts()protected static Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyFromSysfs()Reads processor topology from sysfs using the default CPU path.protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessor.readTopologyWithUdev()Reads processor topology using udev.Method parameters in oshi.hardware.common.platform.linux with type arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionprotected static CentralProcessor.LogicalProcessorLinuxCentralProcessor.getLogicalProcessorFromSyspath(String syspath, Set<CentralProcessor.ProcessorCache> caches, String modAlias, Map<Integer, Integer> coreEfficiencyMap, Map<Integer, String> modAliasMap) getLogicalProcessorFromSyspath. -
Uses of CentralProcessor.ProcessorCache in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.ProcessorCache>, Map<Integer, Integer>, Map<Integer, String>> LinuxCentralProcessorNF.readTopologyWithUdev() -
Uses of CentralProcessor.ProcessorCache in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return types with arguments of type CentralProcessor.ProcessorCacheModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> MacCentralProcessor.initProcessorCounts()