Uses of Interface
oshi.hardware.Display
Packages that use Display
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides common Unix hardware implementations shared by JNA and FFM modules.
-
Uses of Display in oshi.hardware
Methods in oshi.hardware that return types with arguments of type DisplayModifier and TypeMethodDescriptionHardwareAbstractionLayer.getDisplays()Instantiates a list ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.common
Classes in oshi.hardware.common that implement Display -
Uses of Display in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return types with arguments of type Display -
Uses of Display in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement DisplayMethods in oshi.hardware.common.platform.unix that return types with arguments of type Display