Uses of Interface
oshi.hardware.PowerSource
Packages that use PowerSource
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of PowerSource in oshi.hardware
Methods in oshi.hardware that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionHardwareAbstractionLayer.getPowerSources()Instantiates a list ofPowerSourceobjects, representing batteries, etc. -
Uses of PowerSource in oshi.hardware.common
Classes in oshi.hardware.common that implement PowerSourceMethods in oshi.hardware.common that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected abstract List<PowerSource> AbstractPowerSource.queryPowerSources()Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). -
Uses of PowerSource in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement PowerSourceMethods in oshi.hardware.common.platform.linux that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> LinuxPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> LinuxPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement PowerSource