Uses of Enum Class
oshi.hardware.PowerSource.CapacityUnits
Packages that use PowerSource.CapacityUnits
Package
Description
Provides parsing utilities for commands shared by BSD-derived platforms (e.g.
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of PowerSource.CapacityUnits in oshi.driver.common.unix.bsd
Methods in oshi.driver.common.unix.bsd that return PowerSource.CapacityUnits -
Uses of PowerSource.CapacityUnits in oshi.hardware
Subclasses with type arguments of type PowerSource.CapacityUnits in oshi.hardwareMethods in oshi.hardware that return PowerSource.CapacityUnitsModifier and TypeMethodDescriptionPowerSource.getCapacityUnits()Reports =the units ofPowerSource.getCurrentCapacity(),PowerSource.getMaxCapacity(), andPowerSource.getDesignCapacity()static PowerSource.CapacityUnitsReturns the enum constant of this class with the specified name.static PowerSource.CapacityUnits[]PowerSource.CapacityUnits.values()Returns an array containing the constants of this enum class, in the order they are declared. -
Uses of PowerSource.CapacityUnits in oshi.hardware.common
Methods in oshi.hardware.common that return PowerSource.CapacityUnitsConstructors in oshi.hardware.common with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionprotectedAbstractPowerSource(String name, String deviceName, double remainingCapacityPercent, double timeRemainingEstimated, double timeRemainingInstant, double powerUsageRate, double voltage, double amperage, boolean powerOnLine, boolean charging, boolean discharging, PowerSource.CapacityUnits capacityUnits, int currentCapacity, int maxCapacity, int designCapacity, int cycleCount, String chemistry, LocalDate manufactureDate, String manufacturer, String serialNumber, double temperature) Creates an AbstractPowerSource with the given parameters. -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.linux
Constructors in oshi.hardware.common.platform.linux with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionLinuxPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Creates a LinuxPowerSource with the given parameters. -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac with parameters of type PowerSource.CapacityUnitsModifier and TypeMethodDescriptionMacPowerSource.PowerSourceFactory.create(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Constructors in oshi.hardware.common.platform.mac with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionprotectedMacPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Creates a MacPowerSource. -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.unix.aix
Constructors in oshi.hardware.common.platform.unix.aix with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionAixPowerSource(String name, String deviceName, double remainingCapacityPercent, double timeRemainingEstimated, double timeRemainingInstant, double powerUsageRate, double voltage, double amperage, boolean powerOnLine, boolean charging, boolean discharging, PowerSource.CapacityUnits capacityUnits, int currentCapacity, int maxCapacity, int designCapacity, int cycleCount, String chemistry, LocalDate manufactureDate, String manufacturer, String serialNumber, double temperature) -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.unix.freebsd
Methods in oshi.hardware.common.platform.unix.freebsd with parameters of type PowerSource.CapacityUnitsModifier and TypeMethodDescriptionFreeBsdPowerSource.PowerSourceFactory.create(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Constructors in oshi.hardware.common.platform.unix.freebsd with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionprotectedFreeBsdPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.unix.solaris
Methods in oshi.hardware.common.platform.unix.solaris with parameters of type PowerSource.CapacityUnitsModifier and TypeMethodDescriptionSolarisPowerSource.PowerSourceFactory.create(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Constructors in oshi.hardware.common.platform.unix.solaris with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionprotectedSolarisPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Uses of PowerSource.CapacityUnits in oshi.hardware.common.platform.windows
Constructors in oshi.hardware.common.platform.windows with parameters of type PowerSource.CapacityUnitsModifierConstructorDescriptionprotectedWindowsPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) Constructor.