Uses of Enum Class
oshi.hardware.Printer.PrinterStatus
Packages that use Printer.PrinterStatus
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides driver utilities common to unix systems that do not require native access
-
Uses of Printer.PrinterStatus in oshi.hardware
Subclasses with type arguments of type Printer.PrinterStatus in oshi.hardwareMethods in oshi.hardware that return Printer.PrinterStatusModifier and TypeMethodDescriptionPrinter.getStatus()Retrieves the current status of the printer.static Printer.PrinterStatusReturns the enum constant of this class with the specified name.static Printer.PrinterStatus[]Printer.PrinterStatus.values()Returns an array containing the constants of this enum class, in the order they are declared. -
Uses of Printer.PrinterStatus in oshi.hardware.common
Methods in oshi.hardware.common that return Printer.PrinterStatusConstructors in oshi.hardware.common with parameters of type Printer.PrinterStatusModifierConstructorDescriptionprotectedAbstractPrinter(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName) Creates an AbstractPrinter with the given parameters. -
Uses of Printer.PrinterStatus in oshi.hardware.common.platform.unix
Methods in oshi.hardware.common.platform.unix with parameters of type Printer.PrinterStatusModifier and TypeMethodDescriptionCupsPrinter.PrinterFactory.create(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName) Create a printer instance.Constructors in oshi.hardware.common.platform.unix with parameters of type Printer.PrinterStatusModifierConstructorDescriptionprotectedCupsPrinter(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName) Creates a CupsPrinter with the given parameters. -
Uses of Printer.PrinterStatus in oshi.hardware.common.platform.windows
Methods in oshi.hardware.common.platform.windows that return Printer.PrinterStatusModifier and TypeMethodDescriptionprotected static Printer.PrinterStatusWindowsPrinter.parseStatus(int statusCode, int errorState) Parses Win32_Printer PrinterStatus and DetectedErrorState codes.Constructors in oshi.hardware.common.platform.windows with parameters of type Printer.PrinterStatusModifierConstructorDescriptionprotectedWindowsPrinter(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName) Constructor. -
Uses of Printer.PrinterStatus in oshi.util.driver.unix
Methods in oshi.util.driver.unix that return Printer.PrinterStatusModifier and TypeMethodDescriptionstatic Printer.PrinterStatusLpstat.parseStatus(String line) Parse the printer status from an lpstat -p line.