Uses of Class
oshi.hardware.common.AbstractComputerSystem
Packages that use AbstractComputerSystem
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractComputerSystem in oshi.hardware.common.platform.mac
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.mac -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.windows
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.windows