Uses of Class
oshi.hardware.common.AbstractComputerSystem
Packages that use AbstractComputerSystem
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractComputerSystem in oshi.hardware.common.platform.mac
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.mac -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.windows
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.windows