Uses of Class
oshi.hardware.common.AbstractNetworkIF
Packages that use AbstractNetworkIF
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
-
Uses of AbstractNetworkIF in oshi.hardware.common.platform.linux
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.linux -
Uses of AbstractNetworkIF in oshi.hardware.common.platform.linux.nativefree
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux network interface implementation. -
Uses of AbstractNetworkIF in oshi.hardware.common.platform.mac
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassBase class for macOS NetworkIF implementations.