Uses of Class
oshi.hardware.common.AbstractPowerSource
Packages that use AbstractPowerSource
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractPowerSource in oshi.hardware.common.platform.linux
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.linux -
Uses of AbstractPowerSource in oshi.hardware.common.platform.mac
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.mac -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unixModifier and TypeClassDescriptionfinal classShared power-source implementation for BSDs that useapmandsystat -ab sensorsfor battery state (NetBSD, OpenBSD). -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unix.aix -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unix.solarisModifier and TypeClassDescriptionclassAbstract base for the Solaris PowerSource. -
Uses of AbstractPowerSource in oshi.hardware.common.platform.windows
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.windows