Uses of Class
oshi.hardware.common.AbstractPowerSource
Packages that use AbstractPowerSource
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
-
Uses of AbstractPowerSource in oshi.hardware.common.platform.linux
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.linux -
Uses of AbstractPowerSource in oshi.hardware.common.platform.mac
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.mac -
Uses of AbstractPowerSource in oshi.hardware.common.platform.windows
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.windows