Uses of Class
oshi.hardware.common.AbstractSoundCard
Packages that use AbstractSoundCard
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of AbstractSoundCard in oshi.hardware.common.platform.mac
Subclasses of AbstractSoundCard in oshi.hardware.common.platform.macModifier and TypeClassDescriptionfinal classSound card data obtained via AppleHDA kext -
Uses of AbstractSoundCard in oshi.hardware.common.platform.unix
Subclasses of AbstractSoundCard in oshi.hardware.common.platform.unixModifier and TypeClassDescriptionfinal classShared sound card implementation for BSDs that usedmesgaudio/pci patterns (NetBSD, OpenBSD). -
Uses of AbstractSoundCard in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractSoundCard in oshi.hardware.common.platform.unix.aix -
Uses of AbstractSoundCard in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractSoundCard in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractSoundCard in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractSoundCard in oshi.hardware.common.platform.unix.solaris