Uses of Class
oshi.hardware.common.AbstractUsbDevice
Packages that use AbstractUsbDevice
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of AbstractUsbDevice in oshi.hardware.common.platform.linux
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.linux -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.linux.nativefree
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux USB device enumeration from/sys/bus/usb/devices/. -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.mac
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.mac -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.unix
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.unixModifier and TypeClassDescriptionfinal classShared USB device implementation for BSDs that useusbdevs -vto enumerate devices (NetBSD, OpenBSD). -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.unix.aix -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractUsbDevice in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractUsbDevice in oshi.hardware.common.platform.unix.solaris