Enum Class LinuxHWDiskStore.UdevStat
java.lang.Object
java.lang.Enum<LinuxHWDiskStore.UdevStat>
oshi.hardware.common.platform.linux.LinuxHWDiskStore.UdevStat
- All Implemented Interfaces:
Serializable, Comparable<LinuxHWDiskStore.UdevStat>, Constable
- Enclosing class:
LinuxHWDiskStore
Field ordering in udev stat output.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionTime spent doing I/Os in milliseconds.Number of I/Os currently in progress.Number of sectors read.Number of reads completed.Number of sectors written.Number of writes completed. -
Method Summary
Modifier and TypeMethodDescriptionintgetOrder()Gets the field order index.static LinuxHWDiskStore.UdevStatReturns the enum constant of this class with the specified name.static LinuxHWDiskStore.UdevStat[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
READS
Number of reads completed. -
READ_BYTES
Number of sectors read. -
WRITES
Number of writes completed. -
WRITE_BYTES
Number of sectors written. -
QUEUE_LENGTH
Number of I/Os currently in progress. -
ACTIVE_MS
Time spent doing I/Os in milliseconds.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getOrder
public int getOrder()Gets the field order index.- Returns:
- the order
-