Interface IOKitProvider.RegistryEntry
- Enclosing interface:
IOKitProvider
public static interface IOKitProvider.RegistryEntry
A handle to an IORegistry entry, providing property access.
-
Method Summary
Modifier and TypeMethodDescriptiongetBooleanProperty(String key) Gets a boolean property from this registry entry.byte[]Gets a byte array property from this registry entry.getIntegerProperty(String key) Gets an integer property from this registry entry.getName()Gets the name of this registry entry.getStringProperty(String key) Gets a string property from this registry entry.
-
Method Details
-
getName
String getName()Gets the name of this registry entry.- Returns:
- the entry name, or
nullif unavailable
-
getByteArrayProperty
Gets a byte array property from this registry entry.- Parameters:
key- the property key- Returns:
- the property value as a byte array, or
nullif not found
-
getStringProperty
-
getIntegerProperty
-
getBooleanProperty
-