Interface MacGraphicsCard.GraphicsCardFactory
- Enclosing class:
MacGraphicsCard
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Factory for creating GraphicsCard instances.
-
Method Summary
-
Method Details
-
create
Creates a GraphicsCard instance.- Parameters:
name- the card namedeviceId- the device IDvendor- the vendorversionInfo- the version infovram- the VRAM in bytes- Returns:
- the graphics card
-