Interface MacGraphicsCard.GraphicsCardFactory

Enclosing class:
MacGraphicsCard
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface protected static interface MacGraphicsCard.GraphicsCardFactory