Uses of Class
oshi.software.common.AbstractOSProcess
Packages that use AbstractOSProcess
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Uses of AbstractOSProcess in oshi.software.common.os.linux
Subclasses of AbstractOSProcess in oshi.software.common.os.linux -
Uses of AbstractOSProcess in oshi.software.common.os.windows
Subclasses of AbstractOSProcess in oshi.software.common.os.windowsModifier and TypeClassDescriptionclassCommon base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.