Uses of Class
oshi.software.common.AbstractOperatingSystem
Packages that use AbstractOperatingSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Uses of AbstractOperatingSystem in oshi.software.common.os.linux
Subclasses of AbstractOperatingSystem in oshi.software.common.os.linuxModifier and TypeClassDescriptionclassLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds. -
Uses of AbstractOperatingSystem in oshi.software.common.os.linux.nativefree
Subclasses of AbstractOperatingSystem in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux operating system implementation. -
Uses of AbstractOperatingSystem in oshi.software.common.os.mac
Subclasses of AbstractOperatingSystem in oshi.software.common.os.macModifier and TypeClassDescriptionclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001. -
Uses of AbstractOperatingSystem in oshi.software.common.os.windows
Subclasses of AbstractOperatingSystem in oshi.software.common.os.windowsModifier and TypeClassDescriptionclassCommon base class for Windows operating system implementations.