Class LinuxOSProcessNF
java.lang.Object
oshi.software.common.AbstractOSProcess
oshi.software.common.os.linux.LinuxOSProcess
oshi.software.common.os.linux.nativefree.LinuxOSProcessNF
- All Implemented Interfaces:
OSProcess
Native-free Linux OS process implementation. Extends
LinuxOSProcess, providing implementations that require
no native access.-
Nested Class Summary
Nested classes/interfaces inherited from interface OSProcess
OSProcess.State -
Constructor Summary
ConstructorsConstructorDescriptionLinuxOSProcessNF(int pid, LinuxOperatingSystem os) Creates a new native-free Linux OS process. -
Method Summary
Modifier and TypeMethodDescriptionprotected longQueries the hard open file limit for the current process via nativegetrlimit.protected longQueries the soft open file limit for the current process via nativegetrlimit.Methods inherited from class LinuxOSProcess
getAffinityMask, getArguments, getBitness, getBytesRead, getBytesWritten, getCommandLine, getCurrentWorkingDirectory, getEnvironmentVariables, getGroup, getGroupID, getHardOpenFileLimit, getInvoluntaryContextSwitches, getKernelTime, getMajorFaults, getMinorFaults, getName, getOpenFiles, getOs, getParentProcessID, getPath, getPriority, getPrivateResidentMemory, getProcessOpenFileLimit, getResidentMemory, getSoftOpenFileLimit, getStartTime, getState, getThreadCount, getThreadDetails, getUpTime, getUser, getUserID, getUserTime, getVirtualSize, getVoluntaryContextSwitches, updateAttributesMethods inherited from class AbstractOSProcess
getProcessCpuLoadBetweenTicks, getProcessCpuLoadCumulative, getProcessID, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OSProcess
getContextSwitches
-
Constructor Details
-
LinuxOSProcessNF
Creates a new native-free Linux OS process.- Parameters:
pid- the process IDos- the operating system instance
-
-
Method Details
-
queryRlimitSoft
protected long queryRlimitSoft()Description copied from class:LinuxOSProcessQueries the soft open file limit for the current process via nativegetrlimit.- Specified by:
queryRlimitSoftin classLinuxOSProcess- Returns:
- the soft limit value
-
queryRlimitHard
protected long queryRlimitHard()Description copied from class:LinuxOSProcessQueries the hard open file limit for the current process via nativegetrlimit.- Specified by:
queryRlimitHardin classLinuxOSProcess- Returns:
- the hard limit value
-