Class DragonFlyBsdOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.unix.bsd.BsdOperatingSystem
oshi.software.common.os.unix.dragonflybsd.DragonFlyBsdOperatingSystem
- All Implemented Interfaces:
OperatingSystem
Abstract base shared by the DragonFly BSD OperatingSystem implementations (JNA and FFM). The cross-BSD-common pieces
live in
BsdOperatingSystem; this layer adds the DragonFly ps process enumeration (which filters out
the kernel threads that report a negative PID) and the current-thread factory. The native bits (the
OSProcess/FileSystem/NetworkParams/InternetProtocolStats factories,
getpid/lwp_gettid, sysctl version and boot-time queries, and who sessions) are provided by
the JNA and FFM subclasses.-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected abstract OSProcesscreateProcess(int pid, Map<BsdPsKeyword, String> psMap) Creates a backend-specificOSProcessfrom a parsedpsrow.Makes a best effort to get the current thread.getProcessListFromPS(int pid) Enumerates processes (or a single process whenpid >= 0) via the platform'spscommand.Methods inherited from class BsdOperatingSystem
getProcess, getProcessCount, getServices, getSystemBootTime, getSystemUptime, getThreadCount, queryAllProcesses, queryBitness, queryBootTime, queryChildProcesses, queryDescendantProcesses, queryManufacturerModifier and TypeMethodDescriptiongetProcess(int pid) Gets information on a currently running processintGet the number of processes currently runningGets the all services on the system.longGet Unix time of boot.longGet the System up time (time since boot).intGet the number of threads currently runningQueries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failprotected abstract longQueries the system boot time in seconds since the epoch.queryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, queryFamilyVersionInfo, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / Administratorprotected abstract Pair<String, OperatingSystem.OSVersionInfo> Queries the OS family and version info.toString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getFileSystem, getInstalledApplications, getInternetProtocolStats, getNetworkParams, getProcesses, getProcesses, getProcessId, getThreadIdModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.Instantiates aFileSystemobject.default List<ApplicationInfo> Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.Instantiates aNetworkParamsobject.Gets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.intGets the current process ID (PID).intMakes a best effort to get the current thread ID (TID).
-
Constructor Details
-
DragonFlyBsdOperatingSystem
public DragonFlyBsdOperatingSystem()
-
-
Method Details
-
getProcessListFromPS
Description copied from class:BsdOperatingSystemEnumerates processes (or a single process whenpid >= 0) via the platform'spscommand.- Specified by:
getProcessListFromPSin classBsdOperatingSystem- Parameters:
pid- the process ID, or-1for all processes- Returns:
- the process list
-
getCurrentThread
Description copied from interface:OperatingSystemMakes a best effort to get the current thread. May not be useful in a multithreaded environment. The thread returned may have been short lived and no longer exist.On macOS, returns the oldest thread in the calling process.
- Returns:
- the current thread if known; an invalid thread otherwise.
-
createProcess
Creates a backend-specificOSProcessfrom a parsedpsrow.- Parameters:
pid- the process IDpsMap- the parsedpscolumns for this process- Returns:
- a new OSProcess
-