Class NetBsdOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.unix.bsd.BsdOperatingSystem
oshi.software.common.os.unix.netbsd.NetBsdOperatingSystem
- All Implemented Interfaces:
OperatingSystem
NetBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD),
which was based on Research Unix.
The cross-BSD-common pieces live in BsdOperatingSystem; NetBSD has no native-access split, so this single
class also provides the ps process enumeration, the text-parsed boot time, the current-thread factory, and
the sysctl version / file-system / network queries.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionMakes a best effort to get the current thread.Instantiates aFileSystemobject.Instantiates aInternetProtocolStatsobject.Instantiates aNetworkParamsobject.intGets the current process ID (PID).getProcessListFromPS(int pid) Enumerates processes (or a single process whenpid >= 0) via the platform'spscommand.intMakes a best effort to get the current thread ID (TID).protected longQueries the system boot time in seconds since the epoch.Queries the OS family and version info.Methods inherited from class BsdOperatingSystem
getProcess, getProcessCount, getServices, getSystemBootTime, getSystemUptime, getThreadCount, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryManufacturerModifier and TypeMethodDescriptiongetProcess(int pid) Gets information on a currently running processintGet the number of processes currently runningGets the all services on the system.longGet Unix time of boot.longGet the System up time (time since boot).intGet the number of threads currently runningQueries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratortoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getInstalledApplications, getProcesses, getProcessesModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.default List<ApplicationInfo> Retrieves a list of installed applications on the system.Gets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.
-
Constructor Details
-
NetBsdOperatingSystem
public NetBsdOperatingSystem()
-
-
Method Details
-
queryFamilyVersionInfo
Description copied from class:AbstractOperatingSystemQueries the OS family and version info.- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem- Returns:
- a pair of family string and OS version info
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getProcessListFromPS
Description copied from class:BsdOperatingSystemEnumerates processes (or a single process whenpid >= 0) via the platform'spscommand.- Specified by:
getProcessListFromPSin classBsdOperatingSystem- Parameters:
pid- the process ID, or-1for all processes- Returns:
- the process list
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getThreadId
public int getThreadId()Description copied from interface:OperatingSystemMakes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.Thread IDs on macOS are not correlated with any other Operating System output.
- Returns:
- the Thread ID of the current thread if known, 0 otherwise.
-
getCurrentThread
Description copied from interface:OperatingSystemMakes a best effort to get the current thread. May not be useful in a multithreaded environment. The thread returned may have been short lived and no longer exist.On macOS, returns the oldest thread in the calling process.
- Returns:
- the current thread if known; an invalid thread otherwise.
-
queryBootTime
protected long queryBootTime()Description copied from class:BsdOperatingSystemQueries the system boot time in seconds since the epoch.- Specified by:
queryBootTimein classBsdOperatingSystem- Returns:
- the boot time in seconds
-