Class SolarisOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.unix.solaris.SolarisOperatingSystem
- All Implemented Interfaces:
OperatingSystem
Solaris is a non-free Unix operating system originally developed by Sun Microsystems. It superseded the company's
earlier SunOS in 1993. In 2010, after the Sun acquisition by Oracle, it was renamed Oracle Solaris.
Process enumeration, services, and version queries are shared; the native bits (kstat uptime/boot time,
getpid/thr_self, and the OSProcess/FileSystem/NetworkParams/OSThread
factories) are provided by the JNA and FFM subclasses.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected abstract OSProcesscreateProcess(int pid) Creates a platform-specificOSProcessfor the given pid.Instantiates aInternetProtocolStatsobject.getProcess(int pid) Gets information on a currently running processintGet the number of processes currently runningGets the all services on the system.intGet the number of threads currently runningQueries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS family and version info.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratortoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getCurrentThread, getFileSystem, getInstalledApplications, getNetworkParams, getProcesses, getProcesses, getProcessId, getSystemBootTime, getSystemUptime, getThreadIdModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.Makes a best effort to get the current thread.Instantiates aFileSystemobject.default List<ApplicationInfo> Retrieves a list of installed applications on the system.Instantiates aNetworkParamsobject.Gets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.intGets the current process ID (PID).longGet Unix time of boot.longGet the System up time (time since boot).intMakes a best effort to get the current thread ID (TID).
-
Constructor Details
-
SolarisOperatingSystem
public SolarisOperatingSystem()
-
-
Method Details
-
queryManufacturer
Description copied from class:AbstractOperatingSystemQueries the OS manufacturer.- Specified by:
queryManufacturerin classAbstractOperatingSystem- Returns:
- the manufacturer string
-
queryFamilyVersionInfo
Description copied from class:AbstractOperatingSystemQueries the OS family and version info.- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem- Returns:
- a pair of family string and OS version info
-
queryBitness
protected int queryBitness(int jvmBitness) Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
queryAllProcesses
Description copied from class:AbstractOperatingSystemQueries all processes on the system.- Specified by:
queryAllProcessesin classAbstractOperatingSystem- Returns:
- a list of all OS processes
-
queryChildProcesses
Description copied from class:AbstractOperatingSystemQueries the children of a process.- Specified by:
queryChildProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of child processes (including the parent itself)
-
queryDescendantProcesses
Description copied from class:AbstractOperatingSystemQueries the descendants of a process.- Specified by:
queryDescendantProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of descendant processes (including the parent itself)
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Returns:
- An array of
OSServiceobjects
-
createProcess
-