Uses of Package
oshi.software.common

Packages that use oshi.software.common
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.