Uses of Package
oshi.software.common
Packages that use oshi.software.common
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
-
Classes in oshi.software.common used by oshi.software.common.os.linuxClassDescriptionCommon methods for filesystem implementationsCommon implementations for IP StatsCommon NetworkParams implementation.Common methods for OperatingSystem implementationsCommon implementations for OSFileStoreA process is an instance of a computer program that is being executed.Common methods for OSThread implementation
-
Classes in oshi.software.common used by oshi.software.common.os.linux.nativefreeClassDescriptionCommon methods for filesystem implementationsCommon NetworkParams implementation.Common methods for OperatingSystem implementationsA process is an instance of a computer program that is being executed.
-
Classes in oshi.software.common used by oshi.software.common.os.macClassDescriptionCommon methods for filesystem implementationsCommon methods for OperatingSystem implementationsCommon implementations for OSFileStoreCommon methods for OSThread implementation
-
Classes in oshi.software.common used by oshi.software.common.os.windowsClassDescriptionCommon methods for OperatingSystem implementationsCommon implementations for OSFileStoreA process is an instance of a computer program that is being executed.Common methods for OSThread implementation