Uses of Interface
oshi.software.os.OperatingSystem

Packages that use OperatingSystem
Package
Description
Native-free OSHI entry point for Linux.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access