Uses of Interface
oshi.software.os.OperatingSystem
Packages that use OperatingSystem
Package
Description
Native-free OSHI entry point for Linux.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access
-
Uses of OperatingSystem in oshi.nativefree
Methods in oshi.nativefree that return OperatingSystem -
Uses of OperatingSystem in oshi.software.common
Classes in oshi.software.common that implement OperatingSystemModifier and TypeClassDescriptionclassCommon methods for OperatingSystem implementations -
Uses of OperatingSystem in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement OperatingSystemModifier and TypeClassDescriptionclassLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds. -
Uses of OperatingSystem in oshi.software.common.os.linux.nativefree
Classes in oshi.software.common.os.linux.nativefree that implement OperatingSystemModifier and TypeClassDescriptionclassNative-free Linux operating system implementation. -
Uses of OperatingSystem in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement OperatingSystemModifier and TypeClassDescriptionclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001. -
Uses of OperatingSystem in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows that implement OperatingSystemModifier and TypeClassDescriptionclassCommon base class for Windows operating system implementations.Methods in oshi.software.common.os.windows that return OperatingSystemModifier and TypeMethodDescriptionprotected OperatingSystemWindowsOSProcess.getOs()Returns theOperatingSysteminstance associated with this process.Constructors in oshi.software.common.os.windows with parameters of type OperatingSystemModifierConstructorDescriptionprotectedWindowsOSProcess(int pid, OperatingSystem os, Map<Integer, ProcessPerfCounterBlock> processMap, Map<Integer, WtsInfo> processWtsMap, Map<Integer, ThreadPerfCounterBlock> threadMap) Constructor. -
Uses of OperatingSystem in oshi.spi
Methods in oshi.spi that return OperatingSystemModifier and TypeMethodDescriptionSystemInfoProvider.getOperatingSystem()Creates a new instance of the appropriate platform-specificOperatingSystem. -
Uses of OperatingSystem in oshi.util
Methods in oshi.util with parameters of type OperatingSystemModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printOperatingSystem(List<String> lines, OperatingSystem os) Prints Operating System information to the output lines.static voidSystemInfoHelper.printProcesses(List<String> lines, OperatingSystem os, GlobalMemory memory) Prints Processes information to the output lines.static voidSystemInfoHelper.printServices(List<String> lines, OperatingSystem os) Prints Services information to the output lines.